module lcd_controller(
		clk, //50M
		clk_ltm, //25M
		reset_n,
		iMOLECTRL,
		iPANELCTRL,
		oHD,				// LCD Horizontal sync 
		oVD,				// LCD Vertical sync 	
		oDEN,				// LCD Data Enable
		oLCD_R,				// LCD Red color data 
		oLCD_G,             // LCD Green color data  
		oLCD_B,             // LCD Blue color data  
		oVGA_ADDR,
		oVGA_WE_N,
		oVGA_OE_N,
		iVGA_DQ,
		);

//============================================================================
// PARAMETER declarations
//============================================================================
parameter H_LINE = 1056;
parameter V_LINE = 525;
parameter Hsync_Blank = 216;
parameter Hsync_Front_Porch = 40;
parameter Vertical_Back_Porch = 35;
parameter Vertical_Front_Porch = 10;
//=============================================================================	
////IO PORT DECLARATION
//=============================================================================
input clk;
input clk_ltm;
input reset_n;
input [31:0] iMOLECTRL;
input [31:0] iPANELCTRL;
output	[7:0]	oLCD_R;		
output  [7:0]	oLCD_G;
output  [7:0]	oLCD_B;
output	oHD;
output	oVD;
output	oDEN;
output [17:0] oVGA_ADDR;
output oVGA_WE_N;
output oVGA_OE_N;
input [15:0]iVGA_DQ;


///reg and wire
reg		[10:0]  x_cnt;  
reg		[9:0]	y_cnt; 
wire	[7:0]	mred;
wire	[7:0]	mgreen;
wire	[7:0]	mblue; 
wire			display_area;
reg				mhd;
reg				mvd;
reg				mden;
reg				oHD;
reg				oVD;
reg				oDEN;
reg		[7:0]	oLCD_R;
reg		[7:0]	oLCD_G;	
reg		[7:0]	oLCD_B;	
reg		[7:0]	red_1;
reg 	[7:0]	green_1;
reg 	[7:0]	blue_1;

reg [17:0] BACK_ADDR;
wire [17:0] WELCOME_ADDR;
wire [17:0] PLAY_ADDR;
wire [17:0] WIN_ADDR;
wire [17:0] LOSE_ADDR;
reg [17:0] address;
reg [3:0] state;
reg [31:0] mole_ctrl;
reg [31:0] panel_ctrl;

assign oVGA_ADDR = BACK_ADDR;
assign oVGA_WE_N = 1'b0;
assign oVGA_OE_N = display_area ? 1'b1 : 1'b0;
//assign state = iPANELCTRL[3:0];

always@(posedge clk_ltm or negedge reset_n)
	begin
		if (!reset_n)
		begin
		state <= 4'b0;
		mole_ctrl <= 32'b0;
		panel_ctrl <= 32'b0;
		end	
		else if(mvd == 1)
		begin
		state <= iPANELCTRL[3:0];
		mole_ctrl <= iMOLECTRL;
		panel_ctrl <= iPANELCTRL;
		end
		else
		begin
		state <= state;
		mole_ctrl <= mole_ctrl;
		panel_ctrl <= panel_ctrl;
		end
	end
	
// This signal indicate the lcd display area .
assign	display_area = ((x_cnt>(Hsync_Blank-1)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0;


///////////////////////// x  y counter  and lcd hd generator //////////////////
always@(posedge clk_ltm or negedge reset_n)
	begin
		if (!reset_n)
		begin
			x_cnt <= 11'd0;	
			mhd  <= 1'd0;  	
		end	
		else if (x_cnt == (H_LINE-1))
		begin
			x_cnt <= 11'd0;
			mhd  <= 1'd0;
		end	   
		else
		begin
			x_cnt <= x_cnt + 11'd1;
			mhd  <= 1'd1;
		end	
	end

always@(posedge clk_ltm or negedge reset_n)
	begin
		if (!reset_n)
			y_cnt <= 10'd0;
		else if (x_cnt == (H_LINE-1))
		begin
			if (y_cnt == (V_LINE-1))
				y_cnt <= 10'd0;
			else
				y_cnt <= y_cnt + 10'd1;	
		end
	end
////////////////////////////// touch panel timing //////////////////

always@(posedge clk_ltm  or negedge reset_n)
	begin
		if (!reset_n)
			mvd  <= 1'b1;
		else if (y_cnt == 10'd0)
			mvd  <= 1'b0;
		else
			mvd  <= 1'b1;
	end			

always@(posedge clk_ltm  or negedge reset_n)
	begin
		if (!reset_n)
			mden  <= 1'b0;
		else if (display_area)
			mden  <= 1'b1;
		else
			mden  <= 1'b0;
	end

//===========================================================
//Assigning Address===============================================
//===========================================================
always@(posedge clk_ltm or negedge reset_n)
begin
	if(!reset_n)
		BACK_ADDR <= 18'bZ;
	else if (state == 4'b0000 || state==4'b0001 || state ==4'b0010 || state == 4'b0011)
		BACK_ADDR <= WELCOME_ADDR;
	else if (state == 4'b0100 || state==4'b0101 || state ==4'b0110 || state == 4'b0111)
		BACK_ADDR <= PLAY_ADDR;
	else if (state == 4'b1000 || state==4'b1001 || state ==4'b1010 || state == 4'b1011)
		BACK_ADDR <= WIN_ADDR;
	else if (state == 4'b1100 || state==4'b1101 || state ==4'b1110 || state == 4'b1111)
		BACK_ADDR <= LOSE_ADDR;
end

	


//===========================================================
//Welcome Mode===============================================
//===========================================================
welcome welcome1(
				.iclk(clk_ltm),
				.ireset_n(reset_n),
				.ix_cnt(x_cnt),
				.iy_cnt(y_cnt),
				.istate(state),
				.oADDR(WELCOME_ADDR));
				
//===========================================================
//Running Mode===============================================
//===========================================================
play	play1(
				.iclk(clk_ltm),
				.ireset_n(reset_n),
				.ix_cnt(x_cnt), // input from lcd controlelr
				.iy_cnt(y_cnt), // input from lcd controller
				.iPANELCTRL(panel_ctrl), // command from nios containing 32 bits
				.iMOLECTRL(mole_ctrl),
				.oADDR(PLAY_ADDR), //the output address to the lcd controller
					);
//===========================================================
//Win Mode===============================================
//===========================================================
win win1(
				.iclk(clk_ltm),
				.ireset_n(reset_n),
				.ix_cnt(x_cnt),
				.iy_cnt(y_cnt),
				.oADDR(WIN_ADDR));	
//===========================================================
//Lose Mode===============================================
//===========================================================
lose lose1(
				.iclk(clk_ltm),
				.ireset_n(reset_n),
				.ix_cnt(x_cnt),
				.iy_cnt(y_cnt),
				.oADDR(LOSE_ADDR));	

//===========================================================
//OUTPUT LOGIC==============================================
//===========================================================			
always@(posedge clk_ltm or negedge reset_n)
	begin
		if (!reset_n)
			begin
			red_1 <= 8'd255;
			green_1 <= 8'd255;
			blue_1 <= 8'd255;
			end
		else
			begin
			red_1 <= (iVGA_DQ[15:11]<<3);
			green_1 <= (iVGA_DQ[10:5]<<2);
			blue_1 <= (iVGA_DQ[4:0]<<3);
			end
	end
	
///Assign RGB to OUPUT BLOCK	
assign mred = red_1;
assign mgreen = green_1;
assign mblue  = blue_1;	

///////////////////////////////////OUTPUT BLOCK///	////////////////
always@(posedge clk_ltm or negedge reset_n)
	begin
		if (!reset_n)
			begin
				oHD	<= 1'd0;
				oVD	<= 1'd0;
				oDEN <= 1'd0;
				oLCD_R <= 8'd0;
				oLCD_G <= 8'd0;
				oLCD_B <= 8'd0;
			end
		else
			begin
				oHD	<= mhd;
				oVD	<= mvd;
				oDEN <= display_area;
				oLCD_R <= mred;
				oLCD_G <= mgreen;
				oLCD_B <= mblue;
			end		
	end
						
endmodule

