// --------------------------------------------------------------------
// Copyright (c) 2005 by Terasic Technologies Inc. 
// --------------------------------------------------------------------
//
// Permission:
//
//   Terasic grants permission to use and modify this code for use
//   in synthesis for all Terasic Development Boards and Altera Development 
//   Kits made by Terasic.  Other use of this code, including the selling 
//   ,duplication, or modification of any portion is strictly prohibited.
//
// Disclaimer:
//
//   This VHDL/Verilog or C/C++ source code is intended as a design reference
//   which illustrates how these types of functions can be implemented.
//   It is the user's responsibility to verify their design for
//   consistency and functionality through the use of formal
//   verification methods.  Terasic provides no warranty regarding the use 
//   or functionality of this code.
//
// --------------------------------------------------------------------
//           
//                     Terasic Technologies Inc
//                     356 Fu-Shin E. Rd Sec. 1. JhuBei City,
//                     HsinChu County, Taiwan
//                     302
//
//                     web: http://www.terasic.com/
//                     email: support@terasic.com
//
// --------------------------------------------------------------------
//
// Major Functions:	DE2 LTM module Timing control and color pattern 
//					generator
//
// --------------------------------------------------------------------
//
// Revision History :
// --------------------------------------------------------------------
//   Ver  :| Author            		:| Mod. Date :| Changes Made:
//   V1.0 :| Johnny Fan				:| 07/06/30  :| Initial Revision
// --------------------------------------------------------------------
module mole_ctrl		(
						iCLK, 				// LCD display clock
						iRST_n, 			// systen reset
					   x_cnt,  
                  y_cnt, 
						moleControl,
						moleExist,
						mole_address,
						);
//////==================================================
// for every mole control 
//  001 mole up, 000 mole down due to time out
//  101 bottle up, 100 bottle down
//  011 evil up, 010 evil down
//  110 mole hit!!!!
//////==================================================

//============================================================================
// PARAMETER declarations
//============================================================================
parameter H_LINE = 1056;
parameter V_LINE = 525;
parameter Hsync_Blank = 216;
parameter Hsync_Front_Porch = 40;
parameter Vertical_Back_Porch = 35;
parameter Vertical_Front_Porch = 10;
parameter moleBase = 48000;

parameter bottleOffset = 103439-48000;
parameter evilOffset = 117839-48000;
//===========================================================================
// PORT declarations
//===========================================================================
input			iCLK;   
input			iRST_n;
input [10:0] x_cnt;  
input [9:0] y_cnt; 
input [31:0]     moleControl;
output		moleExist;
output[17:0] mole_address;
	
//=============================================================================
// REG/WIRE declarations
//=============================================================================
wire [15:0] area;
wire [1:0] mole0;
wire [1:0] mole1;
wire [1:0] mole2;
wire [1:0] mole3;
wire [1:0] mole4;
wire [1:0] mole5;
wire [1:0] mole6;
wire [1:0] mole7;
wire [1:0] mole8;
wire updn0;
wire updn1;
wire updn2;
wire updn3;
wire updn4;
wire updn5;
wire updn6;
wire updn7;
wire updn8;

reg [9:0]x_offset;
reg [9:0]y_offset;
reg [9:0]abs_x;
reg [9:0]abs_y;
reg [9:0]bound_x;
reg [6:0]hole [0:14];
reg [6:0]moleLeftBound [0:119];
reg [6:0]moleRightBound [0:119];

reg [6:0]bottleLeftBound [0:119];
reg [6:0]bottleRightBound [0:119];

reg [6:0]evilLeftBound [0:119];
reg [6:0]evilRightBound [0:119];

reg [6:0]moleHeight[0:8];
reg [33:0]counter00;
reg [33:0]counter11;
reg [33:0]counter22;
reg [33:0]counter33;
reg [33:0]counter44;
reg [33:0]counter55;
reg [33:0]counter66;
reg [33:0]counter77;
reg [33:0]counter88;

reg [33:0]counter2;
reg [17:0] mole_address;//32000+1
reg [1:0] moleExist ;

//=============================================================================
// Structural coding
//=============================================================================



//generate the bound of the holes
always@(posedge iCLK  or negedge iRST_n)
	begin
		if (!iRST_n)
			   begin
				  hole[0] <= 0;
				  hole[1] <= 0;
				  hole[2] <= 0;				
				  hole[3] <= 0;
				  hole[4] <= 0;
				  hole[5] <= 0;
				  hole[6] <= 0;
				  hole[7] <= 0;
				  hole[8] <= 0;
				  hole[9] <= 0;
				  hole[10] <= 0;
				  hole[11] <= 0;
				  hole[12] <= 0;
				  hole[13] <= 0;
				  hole[14] <= 0;			 
				end  
		else 
            begin
		        hole[0] <= 80;
				  hole[1] <= 80;
				  hole[2] <= 80;
				  hole[3] <= 75;
				  hole[4] <= 75;
				  hole[5] <= 75;
				  hole[6] <= 75;
				  hole[7] <= 75;
				  hole[8] <= 75;
				  hole[9] <= 75;
				  hole[10] <= 70;
				  hole[11] <= 70;
				  hole[12] <= 70;
				  hole[13] <= 65;
				  hole[14] <= 65;			  
            end			
	end	

	
	
//generate the boundmoleHeight of the mole
always@(posedge iCLK or negedge iRST_n)
	begin
		if (!iRST_n)
			   begin
				   moleLeftBound[	0	] <= 	0	;
					moleLeftBound[	1	] <= 	0	;
					moleLeftBound[	2	] <= 	0	;
					moleLeftBound[	3	] <= 	0	;
					moleLeftBound[	4	] <= 	0	;
					moleLeftBound[	5	] <= 	0	;
					moleLeftBound[	6	] <= 	0	;
					moleLeftBound[	7	] <= 	0	;
					moleLeftBound[	8	] <= 	0	;
					moleLeftBound[	9	] <= 	0	;
					moleLeftBound[	10	] <= 	0	;
					moleLeftBound[	11	] <= 	0	;
					moleLeftBound[	12	] <= 	0	;
					moleLeftBound[	13	] <= 	0	;
					moleLeftBound[	14	] <= 	0	;
					moleLeftBound[	15	] <= 	0	;
					moleLeftBound[	16	] <= 	0	;
					moleLeftBound[	17	] <= 	0	;
					moleLeftBound[	18	] <= 	0	;
					moleLeftBound[	19	] <= 	0	;
					moleLeftBound[	20	] <= 	0	;
					moleLeftBound[	21	] <= 	0	;
					moleLeftBound[	22	] <= 	0	;
					moleLeftBound[	23	] <= 	0	;
					moleLeftBound[	24	] <= 	0	;
					moleLeftBound[	25	] <= 	0	;
					moleLeftBound[	26	] <= 	0	;
					moleLeftBound[	27	] <= 	0	;
					moleLeftBound[	28	] <= 	0	;
					moleLeftBound[	29	] <= 	0	;
					moleLeftBound[	30	] <= 	0	;
					moleLeftBound[	31	] <= 	0	;
					moleLeftBound[	32	] <= 	0	;
					moleLeftBound[	33	] <= 	0	;
					moleLeftBound[	34	] <= 	0	;
					moleLeftBound[	35	] <= 	0	;
					moleLeftBound[	36	] <= 	0	;
					moleLeftBound[	37	] <= 	0	;
					moleLeftBound[	38	] <= 	0	;
					moleLeftBound[	39	] <= 	0	;
					moleLeftBound[	40	] <= 	0	;
					moleLeftBound[	41	] <= 	0	;
					moleLeftBound[	42	] <= 	0	;
					moleLeftBound[	43	] <= 	0	;
					moleLeftBound[	44	] <= 	0	;
					moleLeftBound[	45	] <= 	0	;
					moleLeftBound[	46	] <= 	0	;
					moleLeftBound[	47	] <= 	0	;
					moleLeftBound[	48	] <= 	0	;
					moleLeftBound[	49	] <= 	0	;
					moleLeftBound[	50	] <= 	0	;
					moleLeftBound[	51	] <= 	0	;
					moleLeftBound[	52	] <= 	0	;
					moleLeftBound[	53	] <= 	0	;
					moleLeftBound[	54	] <= 	0	;
					moleLeftBound[	55	] <= 	0	;
					moleLeftBound[	56	] <= 	0	;
					moleLeftBound[	57	] <= 	0	;
					moleLeftBound[	58	] <= 	0	;
					moleLeftBound[	59	] <= 	0	;
					moleLeftBound[	60	] <= 	0	;
					moleLeftBound[	61	] <= 	0	;
					moleLeftBound[	62	] <= 	0	;
					moleLeftBound[	63	] <= 	0	;
					moleLeftBound[	64	] <= 	0	;
					moleLeftBound[	65	] <= 	0	;
					moleLeftBound[	66	] <= 	0	;
					moleLeftBound[	67	] <= 	0	;
					moleLeftBound[	68	] <= 	0	;
					moleLeftBound[	69	] <= 	0	;
					moleLeftBound[	70	] <= 	0	;
					moleLeftBound[	71	] <= 	0	;
					moleLeftBound[	72	] <= 	0	;
					moleLeftBound[	73	] <= 	0	;
					moleLeftBound[	74	] <= 	0	;
					moleLeftBound[	75	] <= 	0	;
					moleLeftBound[	76	] <= 	0	;
					moleLeftBound[	77	] <= 	0	;
					moleLeftBound[	78	] <= 	0	;
					moleLeftBound[	79	] <= 	0	;
					moleLeftBound[	80	] <= 	0	;
					moleLeftBound[	81	] <= 	0	;
					moleLeftBound[	82	] <= 	0	;
					moleLeftBound[	83	] <= 	0	;
					moleLeftBound[	84	] <= 	0	;
					moleLeftBound[	85	] <= 	0	;
					moleLeftBound[	86	] <= 	0	;
					moleLeftBound[	87	] <= 	0	;
					moleLeftBound[	88	] <= 	0	;
					moleLeftBound[	89	] <= 	0	;
					moleLeftBound[	90	] <= 	0	;
					moleLeftBound[	91	] <= 	0	;
					moleLeftBound[	92	] <= 	0	;
					moleLeftBound[	93	] <= 	0	;
					moleLeftBound[	94	] <= 	0	;
					moleLeftBound[	95	] <= 	0	;
					moleLeftBound[	96	] <= 	0	;
					moleLeftBound[	97	] <= 	0	;
					moleLeftBound[	98	] <= 	0	;
					moleLeftBound[	99	] <= 	0	;
					moleLeftBound[	100	] <= 	0	;
					moleLeftBound[	101	] <= 	0	;
					moleLeftBound[	102	] <= 	0	;
					moleLeftBound[	103	] <= 	0	;
					moleLeftBound[	104	] <= 	0	;
					moleLeftBound[	105	] <= 	0	;
					moleLeftBound[	106	] <= 	0	;
					moleLeftBound[	107	] <= 	0	;
					moleLeftBound[	108	] <= 	0	;
					moleLeftBound[	109	] <= 	0	;
					moleLeftBound[	110	] <= 	0	;
					moleLeftBound[	111	] <= 	0	;
					moleLeftBound[	112	] <= 	0	;
					moleLeftBound[	113	] <= 	0	;
					moleLeftBound[	114	] <= 	0	;
					moleLeftBound[	115	] <= 	0	;
					moleLeftBound[	116	] <= 	0	;
					moleLeftBound[	117	] <= 	0	;
					moleLeftBound[	118	] <= 	0	;
					moleLeftBound[	119	] <= 	0	;
					
					moleRightBound[	0	] <= 	0	;
					moleRightBound[	1	] <= 	0	;
					moleRightBound[	2	] <= 	0	;
					moleRightBound[	3	] <= 	0	;
					moleRightBound[	4	] <= 	0	;
					moleRightBound[	5	] <= 	0	;
					moleRightBound[	6	] <= 	0	;
					moleRightBound[	7	] <= 	0	;
					moleRightBound[	8	] <= 	0	;
					moleRightBound[	9	] <= 	0	;
					moleRightBound[	10	] <= 	0	;
					moleRightBound[	11	] <= 	0	;
					moleRightBound[	12	] <= 	0	;
					moleRightBound[	13	] <= 	0	;
					moleRightBound[	14	] <= 	0	;
					moleRightBound[	15	] <= 	0	;
					moleRightBound[	16	] <= 	0	;
					moleRightBound[	17	] <= 	0	;
					moleRightBound[	18	] <= 	0	;
					moleRightBound[	19	] <= 	0	;
					moleRightBound[	20	] <= 	0	;
					moleRightBound[	21	] <= 	0	;
					moleRightBound[	22	] <= 	0	;
					moleRightBound[	23	] <= 	0	;
					moleRightBound[	24	] <= 	0	;
					moleRightBound[	25	] <= 	0	;
					moleRightBound[	26	] <= 	0	;
					moleRightBound[	27	] <= 	0	;
					moleRightBound[	28	] <= 	0	;
					moleRightBound[	29	] <= 	0	;
					moleRightBound[	30	] <= 	0	;
					moleRightBound[	31	] <= 	0	;
					moleRightBound[	32	] <= 	0	;
					moleRightBound[	33	] <= 	0	;
					moleRightBound[	34	] <= 	0	;
					moleRightBound[	35	] <= 	0	;
					moleRightBound[	36	] <= 	0	;
					moleRightBound[	37	] <= 	0	;
					moleRightBound[	38	] <= 	0	;
					moleRightBound[	39	] <= 	0	;
					moleRightBound[	40	] <= 	0	;
					moleRightBound[	41	] <= 	0	;
					moleRightBound[	42	] <= 	0	;
					moleRightBound[	43	] <= 	0	;
					moleRightBound[	44	] <= 	0	;
					moleRightBound[	45	] <= 	0	;
					moleRightBound[	46	] <= 	0	;
					moleRightBound[	47	] <= 	0	;
					moleRightBound[	48	] <= 	0	;
					moleRightBound[	49	] <= 	0	;
					moleRightBound[	50	] <= 	0	;
					moleRightBound[	51	] <= 	0	;
					moleRightBound[	52	] <= 	0	;
					moleRightBound[	53	] <= 	0	;
					moleRightBound[	54	] <= 	0	;
					moleRightBound[	55	] <= 	0	;
					moleRightBound[	56	] <= 	0	;
					moleRightBound[	57	] <= 	0	;
					moleRightBound[	58	] <= 	0	;
					moleRightBound[	59	] <= 	0	;
					moleRightBound[	60	] <= 	0	;
					moleRightBound[	61	] <= 	0	;
					moleRightBound[	62	] <= 	0	;
					moleRightBound[	63	] <= 	0	;
					moleRightBound[	64	] <= 	0	;
					moleRightBound[	65	] <= 	0	;
					moleRightBound[	66	] <= 	0	;
					moleRightBound[	67	] <= 	0	;
					moleRightBound[	68	] <= 	0	;
					moleRightBound[	69	] <= 	0	;
					moleRightBound[	70	] <= 	0	;
					moleRightBound[	71	] <= 	0	;
					moleRightBound[	72	] <= 	0	;
					moleRightBound[	73	] <= 	0	;
					moleRightBound[	74	] <= 	0	;
					moleRightBound[	75	] <= 	0	;
					moleRightBound[	76	] <= 	0	;
					moleRightBound[	77	] <= 	0	;
					moleRightBound[	78	] <= 	0	;
					moleRightBound[	79	] <= 	0	;
					moleRightBound[	80	] <= 	0	;
					moleRightBound[	81	] <= 	0	;
					moleRightBound[	82	] <= 	0	;
					moleRightBound[	83	] <= 	0	;
					moleRightBound[	84	] <= 	0	;
					moleRightBound[	85	] <= 	0	;
					moleRightBound[	86	] <= 	0	;
					moleRightBound[	87	] <= 	0	;
					moleRightBound[	88	] <= 	0	;
					moleRightBound[	89	] <= 	0	;
					moleRightBound[	90	] <= 	0	;
					moleRightBound[	91	] <= 	0	;
					moleRightBound[	92	] <= 	0	;
					moleRightBound[	93	] <= 	0	;
					moleRightBound[	94	] <= 	0	;
					moleRightBound[	95	] <= 	0	;
					moleRightBound[	96	] <= 	0	;
					moleRightBound[	97	] <= 	0	;
					moleRightBound[	98	] <= 	0	;
					moleRightBound[	99	] <= 	0	;
					moleRightBound[	100	] <= 	0	;
					moleRightBound[	101	] <= 	0	;
					moleRightBound[	102	] <= 	0	;
					moleRightBound[	103	] <= 	0	;
					moleRightBound[	104	] <= 	0	;
					moleRightBound[	105	] <= 	0	;
					moleRightBound[	106	] <= 	0	;
					moleRightBound[	107	] <= 	0	;
					moleRightBound[	108	] <= 	0	;
					moleRightBound[	109	] <= 	0	;
					moleRightBound[	110	] <= 	0	;
					moleRightBound[	111	] <= 	0	;
					moleRightBound[	112	] <= 	0	;
					moleRightBound[	113	] <= 	0	;
					moleRightBound[	114	] <= 	0	;
					moleRightBound[	115	] <= 	0	;
					moleRightBound[	116	] <= 	0	;
					moleRightBound[	117	] <= 	0	;
					moleRightBound[	118	] <= 	0	;
					moleRightBound[	119	] <= 	0	;
									 
				end  
		else 
            begin
		         moleLeftBound[	0	] <= 	119	;
					moleLeftBound[	1	] <= 	119	;
					moleLeftBound[	2	] <= 	54	;
					moleLeftBound[	3	] <= 	50	;
					moleLeftBound[	4	] <= 	47	;
					moleLeftBound[	5	] <= 	45	;
					moleLeftBound[	6	] <= 	43	;
					moleLeftBound[	7	] <= 	41	;
					moleLeftBound[	8	] <= 	40	;
					moleLeftBound[	9	] <= 	38	;
					moleLeftBound[	10	] <= 	37	;
					moleLeftBound[	11	] <= 	36	;
					moleLeftBound[	12	] <= 	35	;
					moleLeftBound[	13	] <= 	34	;
					moleLeftBound[	14	] <= 	33	;
					moleLeftBound[	15	] <= 	32	;
					moleLeftBound[	16	] <= 	32	;
					moleLeftBound[	17	] <= 	31	;
					moleLeftBound[	18	] <= 	30	;
					moleLeftBound[	19	] <= 	30	;
					moleLeftBound[	20	] <= 	29	;
					moleLeftBound[	21	] <= 	28	;
					moleLeftBound[	22	] <= 	28	;
					moleLeftBound[	23	] <= 	28	;
					moleLeftBound[	24	] <= 	27	;
					moleLeftBound[	25	] <= 	27	;
					moleLeftBound[	26	] <= 	26	;
					moleLeftBound[	27	] <= 	26	;
					moleLeftBound[	28	] <= 	26	;
					moleLeftBound[	29	] <= 	25	;
					moleLeftBound[	30	] <= 	25	;
					moleLeftBound[	31	] <= 	25	;
					moleLeftBound[	32	] <= 	25	;
					moleLeftBound[	33	] <= 	24	;
					moleLeftBound[	34	] <= 	23	;
					moleLeftBound[	35	] <= 	22	;
					moleLeftBound[	36	] <= 	21	;
					moleLeftBound[	37	] <= 	21	;
					moleLeftBound[	38	] <= 	20	;
					moleLeftBound[	39	] <= 	20	;
					moleLeftBound[	40	] <= 	18	;
					moleLeftBound[	41	] <= 	16	;
					moleLeftBound[	42	] <= 	14	;
					moleLeftBound[	43	] <= 	13	;
					moleLeftBound[	44	] <= 	12	;
					moleLeftBound[	45	] <= 	11	;
					moleLeftBound[	46	] <= 	10	;
					moleLeftBound[	47	] <= 	10	;
					moleLeftBound[	48	] <= 	10	;
					moleLeftBound[	49	] <= 	10	;
					moleLeftBound[	50	] <= 	9	;
					moleLeftBound[	51	] <= 	9	;
					moleLeftBound[	52	] <= 	10	;
					moleLeftBound[	53	] <= 	10	;
					moleLeftBound[	54	] <= 	10	;
					moleLeftBound[	55	] <= 	11	;
					moleLeftBound[	56	] <= 	11	;
					moleLeftBound[	57	] <= 	13	;
					moleLeftBound[	58	] <= 	15	;
					moleLeftBound[	59	] <= 	18	;
					moleLeftBound[	60	] <= 	18	;
					moleLeftBound[	61	] <= 	18	;
					moleLeftBound[	62	] <= 	18	;
					moleLeftBound[	63	] <= 	17	;
					moleLeftBound[	64	] <= 	17	;
					moleLeftBound[	65	] <= 	17	;
					moleLeftBound[	66	] <= 	17	;
					moleLeftBound[	67	] <= 	17	;
					moleLeftBound[	68	] <= 	17	;
					moleLeftBound[	69	] <= 	16	;
					moleLeftBound[	70	] <= 	16	;
					moleLeftBound[	71	] <= 	16	;
					moleLeftBound[	72	] <= 	16	;
					moleLeftBound[	73	] <= 	16	;
					moleLeftBound[	74	] <= 	16	;
					moleLeftBound[	75	] <= 	16	;
					moleLeftBound[	76	] <= 	15	;
					moleLeftBound[	77	] <= 	15	;
					moleLeftBound[	78	] <= 	15	;
					moleLeftBound[	79	] <= 	15	;
					moleLeftBound[	80	] <= 	15	;
					moleLeftBound[	81	] <= 	15	;
					moleLeftBound[	82	] <= 	15	;
					moleLeftBound[	83	] <= 	15	;
					moleLeftBound[	84	] <= 	15	;
					moleLeftBound[	85	] <= 	14	;
					moleLeftBound[	86	] <= 	14	;
					moleLeftBound[	87	] <= 	14	;
					moleLeftBound[	88	] <= 	14	;
					moleLeftBound[	89	] <= 	14	;
					moleLeftBound[	90	] <= 	14	;
					moleLeftBound[	91	] <= 	14	;
					moleLeftBound[	92	] <= 	14	;
					moleLeftBound[	93	] <= 	14	;
					moleLeftBound[	94	] <= 	14	;
					moleLeftBound[	95	] <= 	14	;
					moleLeftBound[	96	] <= 	14	;
					moleLeftBound[	97	] <= 	14	;
					moleLeftBound[	98	] <= 	14	;
					moleLeftBound[	99	] <= 	14	;
					moleLeftBound[	100	] <= 	14	;
					moleLeftBound[	101	] <= 	14	;
					moleLeftBound[	102	] <= 	14	;
					moleLeftBound[	103	] <= 	14	;
					moleLeftBound[	104	] <= 	14	;
					moleLeftBound[	105	] <= 	14	;
					moleLeftBound[	106	] <= 	14	;
					moleLeftBound[	107	] <= 	14	;
					moleLeftBound[	108	] <= 	14	;
					moleLeftBound[	109	] <= 	14	;
					moleLeftBound[	110	] <= 	14	;
					moleLeftBound[	111	] <= 	14	;
					moleLeftBound[	112	] <= 	14	;
					moleLeftBound[	113	] <= 	14	;
					moleLeftBound[	114	] <= 	14	;
					moleLeftBound[	115	] <= 	14	;
					moleLeftBound[	116	] <= 	14	;
					moleLeftBound[	117	] <= 	15	;
					moleLeftBound[	118	] <= 	15	;
					moleLeftBound[	119	] <= 	10	;
					
					moleRightBound[	0	] <= 	119	;
					moleRightBound[	1	] <= 	119	;
					moleRightBound[	2	] <= 	67	;
					moleRightBound[	3	] <= 	71	;
					moleRightBound[	4	] <= 	74	;
					moleRightBound[	5	] <= 	76	;
					moleRightBound[	6	] <= 	78	;
					moleRightBound[	7	] <= 	80	;
					moleRightBound[	8	] <= 	81	;
					moleRightBound[	9	] <= 	82	;
					moleRightBound[	10	] <= 	83	;
					moleRightBound[	11	] <= 	85	;
					moleRightBound[	12	] <= 	86	;
					moleRightBound[	13	] <= 	87	;
					moleRightBound[	14	] <= 	88	;
					moleRightBound[	15	] <= 	89	;
					moleRightBound[	16	] <= 	90	;
					moleRightBound[	17	] <= 	90	;
					moleRightBound[	18	] <= 	91	;
					moleRightBound[	19	] <= 	92	;
					moleRightBound[	20	] <= 	92	;
					moleRightBound[	21	] <= 	93	;
					moleRightBound[	22	] <= 	93	;
					moleRightBound[	23	] <= 	94	;
					moleRightBound[	24	] <= 	94	;
					moleRightBound[	25	] <= 	95	;
					moleRightBound[	26	] <= 	95	;
					moleRightBound[	27	] <= 	95	;
					moleRightBound[	28	] <= 	96	;
					moleRightBound[	29	] <= 	96	;
					moleRightBound[	30	] <= 	96	;
					moleRightBound[	31	] <= 	96	;
					moleRightBound[	32	] <= 	96	;
					moleRightBound[	33	] <= 	97	;
					moleRightBound[	34	] <= 	98	;
					moleRightBound[	35	] <= 	99	;
					moleRightBound[	36	] <= 	100	;
					moleRightBound[	37	] <= 	101	;
					moleRightBound[	38	] <= 	101	;
					moleRightBound[	39	] <= 	101	;
					moleRightBound[	40	] <= 	103	;
					moleRightBound[	41	] <= 	105	;
					moleRightBound[	42	] <= 	107	;
					moleRightBound[	43	] <= 	108	;
					moleRightBound[	44	] <= 	109	;
					moleRightBound[	45	] <= 	110	;
					moleRightBound[	46	] <= 	111	;
					moleRightBound[	47	] <= 	111	;
					moleRightBound[	48	] <= 	111	;
					moleRightBound[	49	] <= 	111	;
					moleRightBound[	50	] <= 	112	;
					moleRightBound[	51	] <= 	112	;
					moleRightBound[	52	] <= 	111	;
					moleRightBound[	53	] <= 	111	;
					moleRightBound[	54	] <= 	111	;
					moleRightBound[	55	] <= 	110	;
					moleRightBound[	56	] <= 	110	;
					moleRightBound[	57	] <= 	108	;
					moleRightBound[	58	] <= 	106	;
					moleRightBound[	59	] <= 	104	;
					moleRightBound[	60	] <= 	104	;
					moleRightBound[	61	] <= 	104	;
					moleRightBound[	62	] <= 	104	;
					moleRightBound[	63	] <= 	105	;
					moleRightBound[	64	] <= 	105	;
					moleRightBound[	65	] <= 	105	;
					moleRightBound[	66	] <= 	105	;
					moleRightBound[	67	] <= 	105	;
					moleRightBound[	68	] <= 	105	;
					moleRightBound[	69	] <= 	106	;
					moleRightBound[	70	] <= 	106	;
					moleRightBound[	71	] <= 	106	;
					moleRightBound[	72	] <= 	106	;
					moleRightBound[	73	] <= 	106	;
					moleRightBound[	74	] <= 	106	;
					moleRightBound[	75	] <= 	106	;
					moleRightBound[	76	] <= 	107	;
					moleRightBound[	77	] <= 	107	;
					moleRightBound[	78	] <= 	107	;
					moleRightBound[	79	] <= 	107	;
					moleRightBound[	80	] <= 	107	;
					moleRightBound[	81	] <= 	107	;
					moleRightBound[	82	] <= 	107	;
					moleRightBound[	83	] <= 	107	;
					moleRightBound[	84	] <= 	108	;
					moleRightBound[	85	] <= 	108	;
					moleRightBound[	86	] <= 	108	;
					moleRightBound[	87	] <= 	108	;
					moleRightBound[	88	] <= 	108	;
					moleRightBound[	89	] <= 	108	;
					moleRightBound[	90	] <= 	108	;
					moleRightBound[	91	] <= 	108	;
					moleRightBound[	92	] <= 	108	;
					moleRightBound[	93	] <= 	108	;
					moleRightBound[	94	] <= 	108	;
					moleRightBound[	95	] <= 	108	;
					moleRightBound[	96	] <= 	108	;
					moleRightBound[	97	] <= 	108	;
					moleRightBound[	98	] <= 	108	;
					moleRightBound[	99	] <= 	108	;
					moleRightBound[	100	] <= 	108	;
					moleRightBound[	101	] <= 	108	;
					moleRightBound[	102	] <= 	108	;
					moleRightBound[	103	] <= 	108	;
					moleRightBound[	104	] <= 	108	;
					moleRightBound[	105	] <= 	108	;
					moleRightBound[	106	] <= 	108	;
					moleRightBound[	107	] <= 	108	;
					moleRightBound[	108	] <= 	108	;
					moleRightBound[	109	] <= 	108	;
					moleRightBound[	110	] <= 	108	;
					moleRightBound[	111	] <= 	108	;
					moleRightBound[	112	] <= 	108	;
					moleRightBound[	113	] <= 	108	;
					moleRightBound[	114	] <= 	108	;
					moleRightBound[	115	] <= 	108	;
					moleRightBound[	116	] <= 	108	;
					moleRightBound[	117	] <= 	108	;
					moleRightBound[	118	] <= 	108	;
					moleRightBound[	119	] <= 	108	;
         end			
	end		
	

//generate the boundbottleHeight of the bottle
always@(posedge iCLK or negedge iRST_n)
	begin
		if (!iRST_n)
			   begin
				       bottleLeftBound[	0	] <= 	0	;
					bottleLeftBound[	1	] <= 	0	;
					bottleLeftBound[	2	] <= 	0	;
					bottleLeftBound[	3	] <= 	0	;
					bottleLeftBound[	4	] <= 	0	;
					bottleLeftBound[	5	] <= 	0	;
					bottleLeftBound[	6	] <= 	0	;
					bottleLeftBound[	7	] <= 	0	;
					bottleLeftBound[	8	] <= 	0	;
					bottleLeftBound[	9	] <= 	0	;
					bottleLeftBound[	10	] <= 	0	;
					bottleLeftBound[	11	] <= 	0	;
					bottleLeftBound[	12	] <= 	0	;
					bottleLeftBound[	13	] <= 	0	;
					bottleLeftBound[	14	] <= 	0	;
					bottleLeftBound[	15	] <= 	0	;
					bottleLeftBound[	16	] <= 	0	;
					bottleLeftBound[	17	] <= 	0	;
					bottleLeftBound[	18	] <= 	0	;
					bottleLeftBound[	19	] <= 	0	;
					bottleLeftBound[	20	] <= 	0	;
					bottleLeftBound[	21	] <= 	0	;
					bottleLeftBound[	22	] <= 	0	;
					bottleLeftBound[	23	] <= 	0	;
					bottleLeftBound[	24	] <= 	0	;
					bottleLeftBound[	25	] <= 	0	;
					bottleLeftBound[	26	] <= 	0	;
					bottleLeftBound[	27	] <= 	0	;
					bottleLeftBound[	28	] <= 	0	;
					bottleLeftBound[	29	] <= 	0	;
					bottleLeftBound[	30	] <= 	0	;
					bottleLeftBound[	31	] <= 	0	;
					bottleLeftBound[	32	] <= 	0	;
					bottleLeftBound[	33	] <= 	0	;
					bottleLeftBound[	34	] <= 	0	;
					bottleLeftBound[	35	] <= 	0	;
					bottleLeftBound[	36	] <= 	0	;
					bottleLeftBound[	37	] <= 	0	;
					bottleLeftBound[	38	] <= 	0	;
					bottleLeftBound[	39	] <= 	0	;
					bottleLeftBound[	40	] <= 	0	;
					bottleLeftBound[	41	] <= 	0	;
					bottleLeftBound[	42	] <= 	0	;
					bottleLeftBound[	43	] <= 	0	;
					bottleLeftBound[	44	] <= 	0	;
					bottleLeftBound[	45	] <= 	0	;
					bottleLeftBound[	46	] <= 	0	;
					bottleLeftBound[	47	] <= 	0	;
					bottleLeftBound[	48	] <= 	0	;
					bottleLeftBound[	49	] <= 	0	;
					bottleLeftBound[	50	] <= 	0	;
					bottleLeftBound[	51	] <= 	0	;
					bottleLeftBound[	52	] <= 	0	;
					bottleLeftBound[	53	] <= 	0	;
					bottleLeftBound[	54	] <= 	0	;
					bottleLeftBound[	55	] <= 	0	;
					bottleLeftBound[	56	] <= 	0	;
					bottleLeftBound[	57	] <= 	0	;
					bottleLeftBound[	58	] <= 	0	;
					bottleLeftBound[	59	] <= 	0	;
					bottleLeftBound[	60	] <= 	0	;
					bottleLeftBound[	61	] <= 	0	;
					bottleLeftBound[	62	] <= 	0	;
					bottleLeftBound[	63	] <= 	0	;
					bottleLeftBound[	64	] <= 	0	;
					bottleLeftBound[	65	] <= 	0	;
					bottleLeftBound[	66	] <= 	0	;
					bottleLeftBound[	67	] <= 	0	;
					bottleLeftBound[	68	] <= 	0	;
					bottleLeftBound[	69	] <= 	0	;
					bottleLeftBound[	70	] <= 	0	;
					bottleLeftBound[	71	] <= 	0	;
					bottleLeftBound[	72	] <= 	0	;
					bottleLeftBound[	73	] <= 	0	;
					bottleLeftBound[	74	] <= 	0	;
					bottleLeftBound[	75	] <= 	0	;
					bottleLeftBound[	76	] <= 	0	;
					bottleLeftBound[	77	] <= 	0	;
					bottleLeftBound[	78	] <= 	0	;
					bottleLeftBound[	79	] <= 	0	;
					bottleLeftBound[	80	] <= 	0	;
					bottleLeftBound[	81	] <= 	0	;
					bottleLeftBound[	82	] <= 	0	;
					bottleLeftBound[	83	] <= 	0	;
					bottleLeftBound[	84	] <= 	0	;
					bottleLeftBound[	85	] <= 	0	;
					bottleLeftBound[	86	] <= 	0	;
					bottleLeftBound[	87	] <= 	0	;
					bottleLeftBound[	88	] <= 	0	;
					bottleLeftBound[	89	] <= 	0	;
					bottleLeftBound[	90	] <= 	0	;
					bottleLeftBound[	91	] <= 	0	;
					bottleLeftBound[	92	] <= 	0	;
					bottleLeftBound[	93	] <= 	0	;
					bottleLeftBound[	94	] <= 	0	;
					bottleLeftBound[	95	] <= 	0	;
					bottleLeftBound[	96	] <= 	0	;
					bottleLeftBound[	97	] <= 	0	;
					bottleLeftBound[	98	] <= 	0	;
					bottleLeftBound[	99	] <= 	0	;
					bottleLeftBound[	100	] <= 	0	;
					bottleLeftBound[	101	] <= 	0	;
					bottleLeftBound[	102	] <= 	0	;
					bottleLeftBound[	103	] <= 	0	;
					bottleLeftBound[	104	] <= 	0	;
					bottleLeftBound[	105	] <= 	0	;
					bottleLeftBound[	106	] <= 	0	;
					bottleLeftBound[	107	] <= 	0	;
					bottleLeftBound[	108	] <= 	0	;
					bottleLeftBound[	109	] <= 	0	;
					bottleLeftBound[	110	] <= 	0	;
					bottleLeftBound[	111	] <= 	0	;
					bottleLeftBound[	112	] <= 	0	;
					bottleLeftBound[	113	] <= 	0	;
					bottleLeftBound[	114	] <= 	0	;
					bottleLeftBound[	115	] <= 	0	;
					bottleLeftBound[	116	] <= 	0	;
					bottleLeftBound[	117	] <= 	0	;
					bottleLeftBound[	118	] <= 	0	;
					bottleLeftBound[	119	] <= 	0	;
					
					bottleRightBound[	0	] <= 	0	;
					bottleRightBound[	1	] <= 	0	;
					bottleRightBound[	2	] <= 	0	;
					bottleRightBound[	3	] <= 	0	;
					bottleRightBound[	4	] <= 	0	;
					bottleRightBound[	5	] <= 	0	;
					bottleRightBound[	6	] <= 	0	;
					bottleRightBound[	7	] <= 	0	;
					bottleRightBound[	8	] <= 	0	;
					bottleRightBound[	9	] <= 	0	;
					bottleRightBound[	10	] <= 	0	;
					bottleRightBound[	11	] <= 	0	;
					bottleRightBound[	12	] <= 	0	;
					bottleRightBound[	13	] <= 	0	;
					bottleRightBound[	14	] <= 	0	;
					bottleRightBound[	15	] <= 	0	;
					bottleRightBound[	16	] <= 	0	;
					bottleRightBound[	17	] <= 	0	;
					bottleRightBound[	18	] <= 	0	;
					bottleRightBound[	19	] <= 	0	;
					bottleRightBound[	20	] <= 	0	;
					bottleRightBound[	21	] <= 	0	;
					bottleRightBound[	22	] <= 	0	;
					bottleRightBound[	23	] <= 	0	;
					bottleRightBound[	24	] <= 	0	;
					bottleRightBound[	25	] <= 	0	;
					bottleRightBound[	26	] <= 	0	;
					bottleRightBound[	27	] <= 	0	;
					bottleRightBound[	28	] <= 	0	;
					bottleRightBound[	29	] <= 	0	;
					bottleRightBound[	30	] <= 	0	;
					bottleRightBound[	31	] <= 	0	;
					bottleRightBound[	32	] <= 	0	;
					bottleRightBound[	33	] <= 	0	;
					bottleRightBound[	34	] <= 	0	;
					bottleRightBound[	35	] <= 	0	;
					bottleRightBound[	36	] <= 	0	;
					bottleRightBound[	37	] <= 	0	;
					bottleRightBound[	38	] <= 	0	;
					bottleRightBound[	39	] <= 	0	;
					bottleRightBound[	40	] <= 	0	;
					bottleRightBound[	41	] <= 	0	;
					bottleRightBound[	42	] <= 	0	;
					bottleRightBound[	43	] <= 	0	;
					bottleRightBound[	44	] <= 	0	;
					bottleRightBound[	45	] <= 	0	;
					bottleRightBound[	46	] <= 	0	;
					bottleRightBound[	47	] <= 	0	;
					bottleRightBound[	48	] <= 	0	;
					bottleRightBound[	49	] <= 	0	;
					bottleRightBound[	50	] <= 	0	;
					bottleRightBound[	51	] <= 	0	;
					bottleRightBound[	52	] <= 	0	;
					bottleRightBound[	53	] <= 	0	;
					bottleRightBound[	54	] <= 	0	;
					bottleRightBound[	55	] <= 	0	;
					bottleRightBound[	56	] <= 	0	;
					bottleRightBound[	57	] <= 	0	;
					bottleRightBound[	58	] <= 	0	;
					bottleRightBound[	59	] <= 	0	;
					bottleRightBound[	60	] <= 	0	;
					bottleRightBound[	61	] <= 	0	;
					bottleRightBound[	62	] <= 	0	;
					bottleRightBound[	63	] <= 	0	;
					bottleRightBound[	64	] <= 	0	;
					bottleRightBound[	65	] <= 	0	;
					bottleRightBound[	66	] <= 	0	;
					bottleRightBound[	67	] <= 	0	;
					bottleRightBound[	68	] <= 	0	;
					bottleRightBound[	69	] <= 	0	;
					bottleRightBound[	70	] <= 	0	;
					bottleRightBound[	71	] <= 	0	;
					bottleRightBound[	72	] <= 	0	;
					bottleRightBound[	73	] <= 	0	;
					bottleRightBound[	74	] <= 	0	;
					bottleRightBound[	75	] <= 	0	;
					bottleRightBound[	76	] <= 	0	;
					bottleRightBound[	77	] <= 	0	;
					bottleRightBound[	78	] <= 	0	;
					bottleRightBound[	79	] <= 	0	;
					bottleRightBound[	80	] <= 	0	;
					bottleRightBound[	81	] <= 	0	;
					bottleRightBound[	82	] <= 	0	;
					bottleRightBound[	83	] <= 	0	;
					bottleRightBound[	84	] <= 	0	;
					bottleRightBound[	85	] <= 	0	;
					bottleRightBound[	86	] <= 	0	;
					bottleRightBound[	87	] <= 	0	;
					bottleRightBound[	88	] <= 	0	;
					bottleRightBound[	89	] <= 	0	;
					bottleRightBound[	90	] <= 	0	;
					bottleRightBound[	91	] <= 	0	;
					bottleRightBound[	92	] <= 	0	;
					bottleRightBound[	93	] <= 	0	;
					bottleRightBound[	94	] <= 	0	;
					bottleRightBound[	95	] <= 	0	;
					bottleRightBound[	96	] <= 	0	;
					bottleRightBound[	97	] <= 	0	;
					bottleRightBound[	98	] <= 	0	;
					bottleRightBound[	99	] <= 	0	;
					bottleRightBound[	100	] <= 	0	;
					bottleRightBound[	101	] <= 	0	;
					bottleRightBound[	102	] <= 	0	;
					bottleRightBound[	103	] <= 	0	;
					bottleRightBound[	104	] <= 	0	;
					bottleRightBound[	105	] <= 	0	;
					bottleRightBound[	106	] <= 	0	;
					bottleRightBound[	107	] <= 	0	;
					bottleRightBound[	108	] <= 	0	;
					bottleRightBound[	109	] <= 	0	;
					bottleRightBound[	110	] <= 	0	;
					bottleRightBound[	111	] <= 	0	;
					bottleRightBound[	112	] <= 	0	;
					bottleRightBound[	113	] <= 	0	;
					bottleRightBound[	114	] <= 	0	;
					bottleRightBound[	115	] <= 	0	;
					bottleRightBound[	116	] <= 	0	;
					bottleRightBound[	117	] <= 	0	;
					bottleRightBound[	118	] <= 	0	;
					bottleRightBound[	119	] <= 	0	;
									 
				end  
		else 
            begin
		                                   bottleLeftBound[	  0	] <= 	52       ;
                                                           bottleLeftBound[	  1	] <= 	50	;
                                                           bottleLeftBound[	  2	] <= 	46	;
                                                           bottleLeftBound[	  3	] <= 	46	;
                                                           bottleLeftBound[	  4	] <= 	44	;
                                                           bottleLeftBound[	  5	] <= 	43	;
                                                           bottleLeftBound[	  6	] <= 	42	;
                                                           bottleLeftBound[	  7	] <= 	41	;
                                                           bottleLeftBound[	  8	] <= 	41	;
                                                           bottleLeftBound[	  9	] <= 	40	;
                                                           bottleLeftBound[	  10	] <= 	40	;
                                                           bottleLeftBound[	  11	] <= 	40	;
                                                           bottleLeftBound[	  12	] <= 	40	;
                                                           bottleLeftBound[	  13	] <= 	39	;
                                                           bottleLeftBound[	  14	] <= 	38	;
                                                           bottleLeftBound[	  15	] <= 	37	;
                                                           bottleLeftBound[	  16	] <= 	36	;
                                                           bottleLeftBound[	  17	] <= 	34	;
                                                           bottleLeftBound[	  18	] <= 	33	;
                                                           bottleLeftBound[	  19	] <= 	33	;
                                                           bottleLeftBound[	  20	] <= 	30	;
                                                           bottleLeftBound[	  21	] <= 	31	;
                                                           bottleLeftBound[	  22	] <= 	30	;
                                                           bottleLeftBound[	  23	] <= 	29	;
                                                           bottleLeftBound[	  24	] <= 	28	;
                                                           bottleLeftBound[	  25	] <= 	28	;
                                                           bottleLeftBound[	  26	] <= 	28	;
                                                           bottleLeftBound[	  27	] <= 	28	;
                                                           bottleLeftBound[	  28	] <= 	28	;
                                                           bottleLeftBound[	  29	] <= 	27	;
                                                           bottleLeftBound[	  30	] <= 	27	;
                                                           bottleLeftBound[	  31	] <= 	25	;
                                                           bottleLeftBound[	  32	] <= 	23	;
                                                           bottleLeftBound[	  33	] <= 	22	;
                                                           bottleLeftBound[	  34	] <= 	21	;
                                                           bottleLeftBound[	  35	] <= 	21	;
                                                           bottleLeftBound[	  36	] <= 	20	;
                                                           bottleLeftBound[	  37	] <= 	20	;
                                                           bottleLeftBound[	  38	] <= 	20	;
                                                           bottleLeftBound[	  39	] <= 	20	;
                                                           bottleLeftBound[	  40	] <= 	20	;
                                                           bottleLeftBound[	  41	] <= 	20	;
                                                           bottleLeftBound[	  42	] <= 	20	;
                                                           bottleLeftBound[	  43	] <= 	20	;
                                                           bottleLeftBound[	  44	] <= 	18	;
                                                           bottleLeftBound[	  45	] <= 	16	;
                                                           bottleLeftBound[	  46	] <= 	15	;
                                                           bottleLeftBound[	  47	] <= 	14	;
                                                           bottleLeftBound[	  48	] <= 	13	;
                                                           bottleLeftBound[	  49	] <= 	13	;
                                                           bottleLeftBound[	  50	] <= 	13	;
                                                           bottleLeftBound[	  51	] <= 	13	;
                                                           bottleLeftBound[	  52	] <= 	13	;
                                                           bottleLeftBound[	  53	] <= 	13	;
                                                           bottleLeftBound[	  54	] <= 	13	;
                                                           bottleLeftBound[	  55	] <= 	13	;
                                                           bottleLeftBound[	  56	] <= 	13	;
                                                           bottleLeftBound[	  57	] <= 	13	;
                                                           bottleLeftBound[	  58	] <= 	13	;
                                                           bottleLeftBound[	  59	] <= 	13	;
                                                           bottleLeftBound[	  60	] <= 	13	;
                                                           bottleLeftBound[	  61	] <= 	13	;
                                                           bottleLeftBound[	  62	] <= 	13	;
                                                           bottleLeftBound[	  63	] <= 	13	;
                                                           bottleLeftBound[	  64	] <= 	13	;
                                                           bottleLeftBound[	  65	] <= 	13	;
                                                           bottleLeftBound[	  66	] <= 	13	;
                                                           bottleLeftBound[	  67	] <= 	13	;
                                                           bottleLeftBound[	  68	] <= 	13	;
                                                           bottleLeftBound[	  69	] <= 	13	;
                                                           bottleLeftBound[	  70	] <= 	13	;
                                                           bottleLeftBound[	  71	] <= 	13	;
                                                           bottleLeftBound[	  72	] <= 	13	;
                                                           bottleLeftBound[	  73	] <= 	13	;
                                                           bottleLeftBound[	  74	] <= 	13	;
                                                           bottleLeftBound[	  75	] <= 	13	;
                                                           bottleLeftBound[	  76	] <= 	13	;
                                                           bottleLeftBound[	  77	] <= 	13	;
                                                           bottleLeftBound[	  78	] <= 	13	;
                                                           bottleLeftBound[	  79	] <= 	13	;
                                                           bottleLeftBound[	  80	] <= 	13	;
                                                           bottleLeftBound[	  81	] <= 	13	;
                                                           bottleLeftBound[	  82	] <= 	13	;
                                                           bottleLeftBound[	  83	] <= 	13	;
                                                           bottleLeftBound[	  84	] <= 	13	;
                                                           bottleLeftBound[	  85	] <= 	13	;
                                                           bottleLeftBound[	  86	] <= 	13	;
                                                           bottleLeftBound[	  87	] <= 	13	;
                                                           bottleLeftBound[	  88	] <= 	13	;
                                                           bottleLeftBound[	  89	] <= 	13	;
                                                           bottleLeftBound[	  90	] <= 	13	;
                                                           bottleLeftBound[	  91	] <= 	13	;
                                                           bottleLeftBound[	  92	] <= 	13	;
                                                           bottleLeftBound[	  93	] <= 	13	;
                                                           bottleLeftBound[	  94	] <= 	13	;
                                                           bottleLeftBound[	  95	] <= 	13	;
                                                           bottleLeftBound[	  96	] <= 	13	;
                                                           bottleLeftBound[	  97	] <= 	13	;
                                                           bottleLeftBound[	  98	] <= 	13	;
                                                           bottleLeftBound[	  99	] <= 	13	;
                                                           bottleLeftBound[	  100	] <= 	13	;
                                                           bottleLeftBound[	  101	] <= 	13	;
                                                           bottleLeftBound[	  102	] <= 	13	;
                                                           bottleLeftBound[	  103	] <= 	13	;
                                                           bottleLeftBound[	  104	] <= 	13	;
                                                           bottleLeftBound[	  105	] <= 	13	;
                                                           bottleLeftBound[	  106	] <= 	13	;
                                                           bottleLeftBound[	  107	] <= 	13	;
                                                           bottleLeftBound[	  108	] <= 	13	;
                                                           bottleLeftBound[	  109	] <= 	13	;
                                                           bottleLeftBound[	  110	] <= 	13	;
                                                           bottleLeftBound[	  111	] <= 	13	;
                                                           bottleLeftBound[	  112	] <= 	13	;
                                                           bottleLeftBound[	  113	] <= 	13	;
                                                           bottleLeftBound[	  114	] <= 	14	;
                                                           bottleLeftBound[	  115	] <= 	14	;
                                                           bottleLeftBound[	  116	] <= 	15	;
                                                           bottleLeftBound[	  117	] <= 	17	;
                                                           bottleLeftBound[	  118	] <= 	18	;
                                                           bottleLeftBound[	  119	] <= 	23	;
				
                                                            bottleRightBound[	  0	] <= 	68	;
                                                            bottleRightBound[	  1	] <= 	72	;
                                                            bottleRightBound[	  2	] <= 	75	;
                                                            bottleRightBound[	  3	] <= 	76	;
                                                            bottleRightBound[	  4	] <= 	77	;
                                                            bottleRightBound[	  5	] <= 	78	;
                                                            bottleRightBound[	  6	] <= 	79	;
                                                            bottleRightBound[	  7	] <= 	80	;
                                                            bottleRightBound[	  8	] <= 	81	;
                                                            bottleRightBound[	  9	] <= 	81	;
                                                            bottleRightBound[	  10	] <= 	82	;
                                                            bottleRightBound[	  11	] <= 	82	;
                                                            bottleRightBound[	  12	] <= 	82	;
                                                            bottleRightBound[	  13	] <= 	83	;
                                                            bottleRightBound[	  14	] <= 	84	;
                                                            bottleRightBound[	  15	] <= 	86	;
                                                            bottleRightBound[	  16	] <= 	87	;
                                                            bottleRightBound[	  17	] <= 	88	;
                                                            bottleRightBound[	  18	] <= 	90	;
                                                            bottleRightBound[	  19	] <= 	90	;
                                                            bottleRightBound[	  20	] <= 	92	;
                                                            bottleRightBound[	  21	] <= 	93	;
                                                            bottleRightBound[	  22	] <= 	93	;
                                                            bottleRightBound[	  23	] <= 	94	;
                                                            bottleRightBound[	  24	] <= 	94	;
                                                            bottleRightBound[	  25	] <= 	94	;
                                                            bottleRightBound[	  26	] <= 	95	;
                                                            bottleRightBound[	  27	] <= 	95	;
                                                            bottleRightBound[	  28	] <= 	95	;
                                                            bottleRightBound[	  29	] <= 	95	;
                                                            bottleRightBound[	  30	] <= 	95	;
                                                            bottleRightBound[	  31	] <= 	98	;
                                                            bottleRightBound[	  32	] <= 	100	;
                                                            bottleRightBound[	  33	] <= 	101	;
                                                            bottleRightBound[	  34	] <= 	102	;
                                                            bottleRightBound[	  35	] <= 	102	;
                                                            bottleRightBound[	  36	] <= 	103	;
                                                            bottleRightBound[	  37	] <= 	103	;
                                                            bottleRightBound[	  38	] <= 	103	;
                                                            bottleRightBound[	  39	] <= 	103	;
                                                            bottleRightBound[	  40	] <= 	103	;
                                                            bottleRightBound[	  41	] <= 	103	;
                                                            bottleRightBound[	  42	] <= 	103	;
                                                            bottleRightBound[	  43	] <= 	102	;
                                                            bottleRightBound[	  44	] <= 	103	;
                                                            bottleRightBound[	  45	] <= 	106	;
                                                            bottleRightBound[	  46	] <= 	106	;
                                                            bottleRightBound[	  47	] <= 	105	;
                                                            bottleRightBound[	  48	] <= 	107	;
                                                            bottleRightBound[	  49	] <= 	107	;
                                                            bottleRightBound[	  50	] <= 	107	;
                                                            bottleRightBound[	  51	] <= 	107	;
                                                            bottleRightBound[	  52	] <= 	107	;
                                                            bottleRightBound[	  53	] <= 	107	;
                                                            bottleRightBound[	  54	] <= 	107	;
                                                            bottleRightBound[	  55	] <= 	107	;
                                                            bottleRightBound[	  56	] <= 	107	;
                                                            bottleRightBound[	  57	] <= 	107	;
                                                            bottleRightBound[	  58	] <= 	107	;
                                                            bottleRightBound[	  59	] <= 	107	;
                                                            bottleRightBound[	  60	] <= 	107	;
                                                            bottleRightBound[	  61	] <= 	107	;
                                                            bottleRightBound[	  62	] <= 	107	;
                                                            bottleRightBound[	  63	] <= 	107	;
                                                            bottleRightBound[	  64	] <= 	107	;
                                                            bottleRightBound[	  65	] <= 	107	;
                                                            bottleRightBound[	  66	] <= 	107	;
                                                            bottleRightBound[	  67	] <= 	107	;
                                                            bottleRightBound[	  68	] <= 	107	;
                                                            bottleRightBound[	  69	] <= 	107	;
                                                            bottleRightBound[	  70	] <= 	107	;
                                                            bottleRightBound[	  71	] <= 	107	;
                                                            bottleRightBound[	  72	] <= 	107	;
                                                            bottleRightBound[	  73	] <= 	107	;
                                                            bottleRightBound[	  74	] <= 	107	;
                                                            bottleRightBound[	  75	] <= 	107	;
                                                            bottleRightBound[	  76	] <= 	107	;
                                                            bottleRightBound[	  77	] <= 	107	;
                                                            bottleRightBound[	  78	] <= 	107	;
                                                            bottleRightBound[	  79	] <= 	107	;
                                                            bottleRightBound[	  80	] <= 	107	;
                                                            bottleRightBound[	  81	] <= 	107	;
                                                            bottleRightBound[	  82	] <= 	107	;
                                                            bottleRightBound[	  83	] <= 	107	;
                                                            bottleRightBound[	  84	] <= 	107	;
                                                            bottleRightBound[	  85	] <= 	107	;
                                                            bottleRightBound[	  86	] <= 	107	;
                                                            bottleRightBound[	  87	] <= 	107	;
                                                            bottleRightBound[	  88	] <= 	107	;
                                                            bottleRightBound[	  89	] <= 	107	;
                                                            bottleRightBound[	  90	] <= 	107	;
                                                            bottleRightBound[	  91	] <= 	107	;
                                                            bottleRightBound[	  92	] <= 	107	;
                                                            bottleRightBound[	  93	] <= 	107	;
                                                            bottleRightBound[	  94	] <= 	107	;
                                                            bottleRightBound[	  95	] <= 	107	;
                                                            bottleRightBound[	  96	] <= 	107	;
                                                            bottleRightBound[	  97	] <= 	107	;
                                                            bottleRightBound[	  98	] <= 	107	;
                                                            bottleRightBound[	  99	] <= 	107	;
                                                            bottleRightBound[	  100	] <= 	107	;
                                                            bottleRightBound[	  101	] <= 	107	;
                                                            bottleRightBound[	  102	] <= 	107	;
                                                            bottleRightBound[	  103	] <= 	107	;
                                                            bottleRightBound[	  104	] <= 	107	;
                                                            bottleRightBound[	  105	] <= 	107	;
                                                            bottleRightBound[	  106	] <= 	107	;
                                                            bottleRightBound[	  107	] <= 	107	;
                                                            bottleRightBound[	  108	] <= 	107	;
                                                            bottleRightBound[	  109	] <= 	107	;
                                                            bottleRightBound[	  110	] <= 	107	;
                                                            bottleRightBound[	  111	] <= 	107	;
                                                            bottleRightBound[	  112	] <= 	107	;
                                                            bottleRightBound[	  113	] <= 	107	;
                                                            bottleRightBound[	  114	] <= 	106	;
                                                            bottleRightBound[	  115	] <= 	106	;
                                                            bottleRightBound[	  116	] <= 	105	;
                                                            bottleRightBound[	  117	] <= 	104	;
                                                            bottleRightBound[	  118	] <= 	103	;
                                                            bottleRightBound[	  119	] <= 	98	;
         end			
	end	


//generate the boundevilHeight of the evil
always@(posedge iCLK or negedge iRST_n)
	begin
		if (!iRST_n)
			   begin
				   evilLeftBound[	0	] <= 	0	;
					evilLeftBound[	1	] <= 	0	;
					evilLeftBound[	2	] <= 	0	;
					evilLeftBound[	3	] <= 	0	;
					evilLeftBound[	4	] <= 	0	;
					evilLeftBound[	5	] <= 	0	;
					evilLeftBound[	6	] <= 	0	;
					evilLeftBound[	7	] <= 	0	;
					evilLeftBound[	8	] <= 	0	;
					evilLeftBound[	9	] <= 	0	;
					evilLeftBound[	10	] <= 	0	;
					evilLeftBound[	11	] <= 	0	;
					evilLeftBound[	12	] <= 	0	;
					evilLeftBound[	13	] <= 	0	;
					evilLeftBound[	14	] <= 	0	;
					evilLeftBound[	15	] <= 	0	;
					evilLeftBound[	16	] <= 	0	;
					evilLeftBound[	17	] <= 	0	;
					evilLeftBound[	18	] <= 	0	;
					evilLeftBound[	19	] <= 	0	;
					evilLeftBound[	20	] <= 	0	;
					evilLeftBound[	21	] <= 	0	;
					evilLeftBound[	22	] <= 	0	;
					evilLeftBound[	23	] <= 	0	;
					evilLeftBound[	24	] <= 	0	;
					evilLeftBound[	25	] <= 	0	;
					evilLeftBound[	26	] <= 	0	;
					evilLeftBound[	27	] <= 	0	;
					evilLeftBound[	28	] <= 	0	;
					evilLeftBound[	29	] <= 	0	;
					evilLeftBound[	30	] <= 	0	;
					evilLeftBound[	31	] <= 	0	;
					evilLeftBound[	32	] <= 	0	;
					evilLeftBound[	33	] <= 	0	;
					evilLeftBound[	34	] <= 	0	;
					evilLeftBound[	35	] <= 	0	;
					evilLeftBound[	36	] <= 	0	;
					evilLeftBound[	37	] <= 	0	;
					evilLeftBound[	38	] <= 	0	;
					evilLeftBound[	39	] <= 	0	;
					evilLeftBound[	40	] <= 	0	;
					evilLeftBound[	41	] <= 	0	;
					evilLeftBound[	42	] <= 	0	;
					evilLeftBound[	43	] <= 	0	;
					evilLeftBound[	44	] <= 	0	;
					evilLeftBound[	45	] <= 	0	;
					evilLeftBound[	46	] <= 	0	;
					evilLeftBound[	47	] <= 	0	;
					evilLeftBound[	48	] <= 	0	;
					evilLeftBound[	49	] <= 	0	;
					evilLeftBound[	50	] <= 	0	;
					evilLeftBound[	51	] <= 	0	;
					evilLeftBound[	52	] <= 	0	;
					evilLeftBound[	53	] <= 	0	;
					evilLeftBound[	54	] <= 	0	;
					evilLeftBound[	55	] <= 	0	;
					evilLeftBound[	56	] <= 	0	;
					evilLeftBound[	57	] <= 	0	;
					evilLeftBound[	58	] <= 	0	;
					evilLeftBound[	59	] <= 	0	;
					evilLeftBound[	60	] <= 	0	;
					evilLeftBound[	61	] <= 	0	;
					evilLeftBound[	62	] <= 	0	;
					evilLeftBound[	63	] <= 	0	;
					evilLeftBound[	64	] <= 	0	;
					evilLeftBound[	65	] <= 	0	;
					evilLeftBound[	66	] <= 	0	;
					evilLeftBound[	67	] <= 	0	;
					evilLeftBound[	68	] <= 	0	;
					evilLeftBound[	69	] <= 	0	;
					evilLeftBound[	70	] <= 	0	;
					evilLeftBound[	71	] <= 	0	;
					evilLeftBound[	72	] <= 	0	;
					evilLeftBound[	73	] <= 	0	;
					evilLeftBound[	74	] <= 	0	;
					evilLeftBound[	75	] <= 	0	;
					evilLeftBound[	76	] <= 	0	;
					evilLeftBound[	77	] <= 	0	;
					evilLeftBound[	78	] <= 	0	;
					evilLeftBound[	79	] <= 	0	;
					evilLeftBound[	80	] <= 	0	;
					evilLeftBound[	81	] <= 	0	;
					evilLeftBound[	82	] <= 	0	;
					evilLeftBound[	83	] <= 	0	;
					evilLeftBound[	84	] <= 	0	;
					evilLeftBound[	85	] <= 	0	;
					evilLeftBound[	86	] <= 	0	;
					evilLeftBound[	87	] <= 	0	;
					evilLeftBound[	88	] <= 	0	;
					evilLeftBound[	89	] <= 	0	;
					evilLeftBound[	90	] <= 	0	;
					evilLeftBound[	91	] <= 	0	;
					evilLeftBound[	92	] <= 	0	;
					evilLeftBound[	93	] <= 	0	;
					evilLeftBound[	94	] <= 	0	;
					evilLeftBound[	95	] <= 	0	;
					evilLeftBound[	96	] <= 	0	;
					evilLeftBound[	97	] <= 	0	;
					evilLeftBound[	98	] <= 	0	;
					evilLeftBound[	99	] <= 	0	;
					evilLeftBound[	100	] <= 	0	;
					evilLeftBound[	101	] <= 	0	;
					evilLeftBound[	102	] <= 	0	;
					evilLeftBound[	103	] <= 	0	;
					evilLeftBound[	104	] <= 	0	;
					evilLeftBound[	105	] <= 	0	;
					evilLeftBound[	106	] <= 	0	;
					evilLeftBound[	107	] <= 	0	;
					evilLeftBound[	108	] <= 	0	;
					evilLeftBound[	109	] <= 	0	;
					evilLeftBound[	110	] <= 	0	;
					evilLeftBound[	111	] <= 	0	;
					evilLeftBound[	112	] <= 	0	;
					evilLeftBound[	113	] <= 	0	;
					evilLeftBound[	114	] <= 	0	;
					evilLeftBound[	115	] <= 	0	;
					evilLeftBound[	116	] <= 	0	;
					evilLeftBound[	117	] <= 	0	;
					evilLeftBound[	118	] <= 	0	;
					evilLeftBound[	119	] <= 	0	;
					
					evilRightBound[	0	] <= 	0	;
					evilRightBound[	1	] <= 	0	;
					evilRightBound[	2	] <= 	0	;
					evilRightBound[	3	] <= 	0	;
					evilRightBound[	4	] <= 	0	;
					evilRightBound[	5	] <= 	0	;
					evilRightBound[	6	] <= 	0	;
					evilRightBound[	7	] <= 	0	;
					evilRightBound[	8	] <= 	0	;
					evilRightBound[	9	] <= 	0	;
					evilRightBound[	10	] <= 	0	;
					evilRightBound[	11	] <= 	0	;
					evilRightBound[	12	] <= 	0	;
					evilRightBound[	13	] <= 	0	;
					evilRightBound[	14	] <= 	0	;
					evilRightBound[	15	] <= 	0	;
					evilRightBound[	16	] <= 	0	;
					evilRightBound[	17	] <= 	0	;
					evilRightBound[	18	] <= 	0	;
					evilRightBound[	19	] <= 	0	;
					evilRightBound[	20	] <= 	0	;
					evilRightBound[	21	] <= 	0	;
					evilRightBound[	22	] <= 	0	;
					evilRightBound[	23	] <= 	0	;
					evilRightBound[	24	] <= 	0	;
					evilRightBound[	25	] <= 	0	;
					evilRightBound[	26	] <= 	0	;
					evilRightBound[	27	] <= 	0	;
					evilRightBound[	28	] <= 	0	;
					evilRightBound[	29	] <= 	0	;
					evilRightBound[	30	] <= 	0	;
					evilRightBound[	31	] <= 	0	;
					evilRightBound[	32	] <= 	0	;
					evilRightBound[	33	] <= 	0	;
					evilRightBound[	34	] <= 	0	;
					evilRightBound[	35	] <= 	0	;
					evilRightBound[	36	] <= 	0	;
					evilRightBound[	37	] <= 	0	;
					evilRightBound[	38	] <= 	0	;
					evilRightBound[	39	] <= 	0	;
					evilRightBound[	40	] <= 	0	;
					evilRightBound[	41	] <= 	0	;
					evilRightBound[	42	] <= 	0	;
					evilRightBound[	43	] <= 	0	;
					evilRightBound[	44	] <= 	0	;
					evilRightBound[	45	] <= 	0	;
					evilRightBound[	46	] <= 	0	;
					evilRightBound[	47	] <= 	0	;
					evilRightBound[	48	] <= 	0	;
					evilRightBound[	49	] <= 	0	;
					evilRightBound[	50	] <= 	0	;
					evilRightBound[	51	] <= 	0	;
					evilRightBound[	52	] <= 	0	;
					evilRightBound[	53	] <= 	0	;
					evilRightBound[	54	] <= 	0	;
					evilRightBound[	55	] <= 	0	;
					evilRightBound[	56	] <= 	0	;
					evilRightBound[	57	] <= 	0	;
					evilRightBound[	58	] <= 	0	;
					evilRightBound[	59	] <= 	0	;
					evilRightBound[	60	] <= 	0	;
					evilRightBound[	61	] <= 	0	;
					evilRightBound[	62	] <= 	0	;
					evilRightBound[	63	] <= 	0	;
					evilRightBound[	64	] <= 	0	;
					evilRightBound[	65	] <= 	0	;
					evilRightBound[	66	] <= 	0	;
					evilRightBound[	67	] <= 	0	;
					evilRightBound[	68	] <= 	0	;
					evilRightBound[	69	] <= 	0	;
					evilRightBound[	70	] <= 	0	;
					evilRightBound[	71	] <= 	0	;
					evilRightBound[	72	] <= 	0	;
					evilRightBound[	73	] <= 	0	;
					evilRightBound[	74	] <= 	0	;
					evilRightBound[	75	] <= 	0	;
					evilRightBound[	76	] <= 	0	;
					evilRightBound[	77	] <= 	0	;
					evilRightBound[	78	] <= 	0	;
					evilRightBound[	79	] <= 	0	;
					evilRightBound[	80	] <= 	0	;
					evilRightBound[	81	] <= 	0	;
					evilRightBound[	82	] <= 	0	;
					evilRightBound[	83	] <= 	0	;
					evilRightBound[	84	] <= 	0	;
					evilRightBound[	85	] <= 	0	;
					evilRightBound[	86	] <= 	0	;
					evilRightBound[	87	] <= 	0	;
					evilRightBound[	88	] <= 	0	;
					evilRightBound[	89	] <= 	0	;
					evilRightBound[	90	] <= 	0	;
					evilRightBound[	91	] <= 	0	;
					evilRightBound[	92	] <= 	0	;
					evilRightBound[	93	] <= 	0	;
					evilRightBound[	94	] <= 	0	;
					evilRightBound[	95	] <= 	0	;
					evilRightBound[	96	] <= 	0	;
					evilRightBound[	97	] <= 	0	;
					evilRightBound[	98	] <= 	0	;
					evilRightBound[	99	] <= 	0	;
					evilRightBound[	100	] <= 	0	;
					evilRightBound[	101	] <= 	0	;
					evilRightBound[	102	] <= 	0	;
					evilRightBound[	103	] <= 	0	;
					evilRightBound[	104	] <= 	0	;
					evilRightBound[	105	] <= 	0	;
					evilRightBound[	106	] <= 	0	;
					evilRightBound[	107	] <= 	0	;
					evilRightBound[	108	] <= 	0	;
					evilRightBound[	109	] <= 	0	;
					evilRightBound[	110	] <= 	0	;
					evilRightBound[	111	] <= 	0	;
					evilRightBound[	112	] <= 	0	;
					evilRightBound[	113	] <= 	0	;
					evilRightBound[	114	] <= 	0	;
					evilRightBound[	115	] <= 	0	;
					evilRightBound[	116	] <= 	0	;
					evilRightBound[	117	] <= 	0	;
					evilRightBound[	118	] <= 	0	;
					evilRightBound[	119	] <= 	0	;
									 
				end  
		else 
            begin
		                                    evilLeftBound[	0	] <= 	57	;
                           evilLeftBound[	1	] <= 	51	;
                           evilLeftBound[	2	] <= 	47	;
                           evilLeftBound[	3	] <= 	44	;
                           evilLeftBound[	4	] <= 	42	;
                           evilLeftBound[	5	] <= 	38	;
                           evilLeftBound[	6	] <= 	36	;
                           evilLeftBound[	7	] <= 	36	;
                           evilLeftBound[	8	] <= 	33	;
                           evilLeftBound[	9	] <= 	32	;
                           evilLeftBound[	10	] <= 	31	;
                           evilLeftBound[	11	] <= 	29	;
                           evilLeftBound[	12	] <= 	28	;
                           evilLeftBound[	13	] <= 	26	;
                           evilLeftBound[	14	] <= 	24	;
                           evilLeftBound[	15	] <= 	24	;
                           evilLeftBound[	16	] <= 	20	;
                           evilLeftBound[	17	] <= 	20	;
                           evilLeftBound[	18	] <= 	20	;
                           evilLeftBound[	19	] <= 	20	;
                           evilLeftBound[	20	] <= 	19	;
                           evilLeftBound[	21	] <= 	18	;
                           evilLeftBound[	22	] <= 	18	;
                           evilLeftBound[	23	] <= 	16	;
                           evilLeftBound[	24	] <= 	16	;
                           evilLeftBound[	25	] <= 	16	;
                           evilLeftBound[	26	] <= 	13	;
                           evilLeftBound[	27	] <= 	13	;
                           evilLeftBound[	28	] <= 	13	;
                           evilLeftBound[	29	] <= 	13	;
                           evilLeftBound[	30	] <= 	12	;
                           evilLeftBound[	31	] <= 	10	;
                           evilLeftBound[	32	] <= 	11	;
                           evilLeftBound[	33	] <= 	10	;
                           evilLeftBound[	34	] <= 	9	;
                           evilLeftBound[	35	] <= 	10	;
                           evilLeftBound[	36	] <= 	9	;
                           evilLeftBound[	37	] <= 	9	;
                           evilLeftBound[	38	] <= 	9	;
                           evilLeftBound[	39	] <= 	9	;
                           evilLeftBound[	40	] <= 	9	;
                           evilLeftBound[	41	] <= 	7	;
                           evilLeftBound[	42	] <= 	7	;
                           evilLeftBound[	43	] <= 	7	;
                           evilLeftBound[	44	] <= 	7	;
                           evilLeftBound[	45	] <= 	7	;
                           evilLeftBound[	46	] <= 	7	;
                           evilLeftBound[	47	] <= 	7	;
                           evilLeftBound[	48	] <= 	6	;
                           evilLeftBound[	49	] <= 	7	;
                           evilLeftBound[	50	] <= 	7	;
                           evilLeftBound[	51	] <= 	6	;
                           evilLeftBound[	52	] <= 	6	;
                           evilLeftBound[	53	] <= 	6	;
                           evilLeftBound[	54	] <= 	6	;
                           evilLeftBound[	55	] <= 	6	;
                           evilLeftBound[	56	] <= 	6	;
                           evilLeftBound[	57	] <= 	6	;
                           evilLeftBound[	58	] <= 	6	;
                           evilLeftBound[	59	] <= 	6	;
                           evilLeftBound[	60	] <= 	7	;
                           evilLeftBound[	61	] <= 	7	;
                           evilLeftBound[	62	] <= 	7	;
                           evilLeftBound[	63	] <= 	7	;
                           evilLeftBound[	64	] <= 	7	;
                           evilLeftBound[	65	] <= 	7	;
                           evilLeftBound[	66	] <= 	7	;
                           evilLeftBound[	67	] <= 	8	;
                           evilLeftBound[	68	] <= 	8	;
                           evilLeftBound[	69	] <= 	9	;
                           evilLeftBound[	70	] <= 	9	;
                           evilLeftBound[	71	] <= 	10	;
                           evilLeftBound[	72	] <= 	10	;
                           evilLeftBound[	73	] <= 	10	;
                           evilLeftBound[	74	] <= 	11	;
                           evilLeftBound[	75	] <= 	11	;
                           evilLeftBound[	76	] <= 	11	;
                           evilLeftBound[	77	] <= 	12	;
                           evilLeftBound[	78	] <= 	14	;
                           evilLeftBound[	79	] <= 	14	;
                           evilLeftBound[	80	] <= 	15	;
                           evilLeftBound[	81	] <= 	15	;
                           evilLeftBound[	82	] <= 	16	;
                           evilLeftBound[	83	] <= 	17	;
                           evilLeftBound[	84	] <= 	18	;
                           evilLeftBound[	85	] <= 	19	;
                           evilLeftBound[	86	] <= 	20	;
                           evilLeftBound[	87	] <= 	19	;
                           evilLeftBound[	88	] <= 	21	;
                           evilLeftBound[	89	] <= 	23	;
                           evilLeftBound[	90	] <= 	24	;
                           evilLeftBound[	91	] <= 	25	;
                           evilLeftBound[	92	] <= 	23	;
                           evilLeftBound[	93	] <= 	27	;
                           evilLeftBound[	94	] <= 	27	;
                           evilLeftBound[	95	] <= 	28	;
                           evilLeftBound[	96	] <= 	28	;
                           evilLeftBound[	97	] <= 	28	;
                           evilLeftBound[	98	] <= 	28	;
                           evilLeftBound[	99	] <= 	27	;
                           evilLeftBound[	100	] <= 	27	;
                           evilLeftBound[	101	] <= 	27	;
                           evilLeftBound[	102	] <= 	27	;
                           evilLeftBound[	103	] <= 	27	;
                           evilLeftBound[	104	] <= 	27	;
                           evilLeftBound[	105	] <= 	27	;
                           evilLeftBound[	106	] <= 	27	;
                           evilLeftBound[	107	] <= 	27	;
                           evilLeftBound[	108	] <= 	28	;
                           evilLeftBound[	109	] <= 	27	;
                           evilLeftBound[	110	] <= 	27	;
                           evilLeftBound[	111	] <= 	27	;
                           evilLeftBound[	112	] <= 	27	;
                           evilLeftBound[	113	] <= 	28	;
                           evilLeftBound[	114	] <= 	28	;
                           evilLeftBound[	115	] <= 	28	;
                           evilLeftBound[	116	] <= 	29	;
                           evilLeftBound[	117	] <= 	29	;
                           evilLeftBound[	118	] <= 	29	;
                           evilLeftBound[	119	] <= 	30	;
				
                           evilRightBound[	0	] <= 	58	;
                           evilRightBound[	1	] <= 	70	;
                           evilRightBound[	2	] <= 	74	;
                           evilRightBound[	3	] <= 	77	;
                           evilRightBound[	4	] <= 	82	;
                           evilRightBound[	5	] <= 	81	;
                           evilRightBound[	6	] <= 	84	;
                           evilRightBound[	7	] <= 	85	;
                           evilRightBound[	8	] <= 	87	;
                           evilRightBound[	9	] <= 	90	;
                           evilRightBound[	10	] <= 	90	;
                           evilRightBound[	11	] <= 	91	;
                           evilRightBound[	12	] <= 	93	;
                           evilRightBound[	13	] <= 	94	;
                           evilRightBound[	14	] <= 	95	;
                           evilRightBound[	15	] <= 	96	;
                           evilRightBound[	16	] <= 	97	;
                           evilRightBound[	17	] <= 	21	;
                           evilRightBound[	18	] <= 	99	;
                           evilRightBound[	19	] <= 	100	;
                           evilRightBound[	20	] <= 	101	;
                           evilRightBound[	21	] <= 	101	;
                           evilRightBound[	22	] <= 	102	;
                           evilRightBound[	23	] <= 	103	;
                           evilRightBound[	24	] <= 	103	;
                           evilRightBound[	25	] <= 	104	;
                           evilRightBound[	26	] <= 	104	;
                           evilRightBound[	27	] <= 	106	;
                           evilRightBound[	28	] <= 	107	;
                           evilRightBound[	29	] <= 	107	;
                           evilRightBound[	30	] <= 	107	;
                           evilRightBound[	31	] <= 	107	;
                           evilRightBound[	32	] <= 	108	;
                           evilRightBound[	33	] <= 	109	;
                           evilRightBound[	34	] <= 	109	;
                           evilRightBound[	35	] <= 	109	;
                           evilRightBound[	36	] <= 	110	;
                           evilRightBound[	37	] <= 	110	;
                           evilRightBound[	38	] <= 	110	;
                           evilRightBound[	39	] <= 	111	;
                           evilRightBound[	40	] <= 	111	;
                           evilRightBound[	41	] <= 	112	;
                           evilRightBound[	42	] <= 	112	;
                           evilRightBound[	43	] <= 	112	;
                           evilRightBound[	44	] <= 	112	;
                           evilRightBound[	45	] <= 	112	;
                           evilRightBound[	46	] <= 	113	;
                           evilRightBound[	47	] <= 	113	;
                           evilRightBound[	48	] <= 	113	;
                           evilRightBound[	49	] <= 	114	;
                           evilRightBound[	50	] <= 	114	;
                           evilRightBound[	51	] <= 	114	;
                           evilRightBound[	52	] <= 	114	;
                           evilRightBound[	53	] <= 	114	;
                           evilRightBound[	54	] <= 	114	;
                           evilRightBound[	55	] <= 	114	;
                           evilRightBound[	56	] <= 	114	;
                           evilRightBound[	57	] <= 	114	;
                           evilRightBound[	58	] <= 	114	;
                           evilRightBound[	59	] <= 	114	;
                           evilRightBound[	60	] <= 	114	;
                           evilRightBound[	61	] <= 	114	;
                           evilRightBound[	62	] <= 	114	;
                           evilRightBound[	63	] <= 	114	;
                           evilRightBound[	64	] <= 	113	;
                           evilRightBound[	65	] <= 	113	;
                           evilRightBound[	66	] <= 	113	;
                           evilRightBound[	67	] <= 	113	;
                           evilRightBound[	68	] <= 	112	;
                           evilRightBound[	69	] <= 	112	;
                           evilRightBound[	70	] <= 	112	;
                           evilRightBound[	71	] <= 	111	;
                           evilRightBound[	72	] <= 	112	;
                           evilRightBound[	73	] <= 	110	;
                           evilRightBound[	74	] <= 	110	;
                           evilRightBound[	75	] <= 	110	;
                           evilRightBound[	76	] <= 	109	;
                           evilRightBound[	77	] <= 	109	;
                           evilRightBound[	78	] <= 	108	;
                           evilRightBound[	79	] <= 	108	;
                           evilRightBound[	80	] <= 	108	;
                           evilRightBound[	81	] <= 	108	;
                           evilRightBound[	82	] <= 	106	;
                           evilRightBound[	83	] <= 	105	;
                           evilRightBound[	84	] <= 	104	;
                           evilRightBound[	85	] <= 	104	;
                           evilRightBound[	86	] <= 	104	;
                           evilRightBound[	87	] <= 	102	;
                           evilRightBound[	88	] <= 	103	;
                           evilRightBound[	89	] <= 	100	;
                           evilRightBound[	90	] <= 	99	;
                           evilRightBound[	91	] <= 	98	;
                           evilRightBound[	92	] <= 	97	;
                           evilRightBound[	93	] <= 	95	;
                           evilRightBound[	94	] <= 	95	;
                           evilRightBound[	95	] <= 	94	;
                           evilRightBound[	96	] <= 	94	;
                           evilRightBound[	97	] <= 	94	;
                           evilRightBound[	98	] <= 	94	;
                           evilRightBound[	99	] <= 	94	;
                           evilRightBound[	100	] <= 	94	;
                           evilRightBound[	101	] <= 	94	;
                           evilRightBound[	102	] <= 	94	;
                           evilRightBound[	103	] <= 	94	;
                           evilRightBound[	104	] <= 	94	;
                           evilRightBound[	105	] <= 	94	;
                           evilRightBound[	106	] <= 	94	;
                           evilRightBound[	107	] <= 	94	;
                           evilRightBound[	108	] <= 	94	;
                           evilRightBound[	109	] <= 	94	;
                           evilRightBound[	110	] <= 	94	;
                           evilRightBound[	111	] <= 	94	;
                           evilRightBound[	112	] <= 	94	;
                           evilRightBound[	113	] <= 	94	;
                           evilRightBound[	114	] <= 	93	;
                           evilRightBound[	115	] <= 	94	;
                           evilRightBound[	116	] <= 	93	;
                           evilRightBound[	117	] <= 	93	;
                           evilRightBound[	118	] <= 	93	;
                           evilRightBound[	119	] <= 	92	;
         end			
	end		

	assign mole0[0] = moleControl[0] ? 1: 0;
       assign mole0[1] = moleControl[1] ? 1: 0;
       assign updn0 = moleControl[2] ? 1: 0;

       assign mole1[0] = moleControl[3] ? 1: 0;
       assign mole1[1] = moleControl[4] ? 1: 0;
       assign updn1 = moleControl[5] ? 1: 0;

       assign mole2[0] = moleControl[6] ? 1: 0;
       assign mole2[1] = moleControl[7] ? 1: 0;
       assign updn2 = moleControl[8] ? 1: 0;


       assign mole3[0] = moleControl[9] ? 1: 0;
       assign mole3[1] = moleControl[10] ? 1: 0;
       assign updn3 = moleControl[11] ? 1: 0;

       assign mole4[0] = moleControl[12] ? 1: 0;
       assign mole4[1] = moleControl[13] ? 1: 0;
       assign updn4 = moleControl[14] ? 1: 0;

       assign mole5[0] = moleControl[15] ? 1: 0;
       assign mole5[1] = moleControl[16] ? 1: 0;
       assign updn5 = moleControl[17] ? 1: 0;

       assign mole6[0] = moleControl[18] ? 1: 0;
       assign mole6[1] = moleControl[19] ? 1: 0;
       assign updn6 = moleControl[20] ? 1: 0;

       assign mole7[0] = moleControl[21] ? 1: 0;
       assign mole7[1] = moleControl[22] ? 1: 0;
       assign updn7 = moleControl[23] ? 1: 0;

       assign mole8[0] = moleControl[24] ? 1: 0;
       assign mole8[1] = moleControl[25] ? 1: 0;
       assign updn8 = moleControl[26] ? 1: 0;

	
//Calculate the height of the mole0
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[0] <= 0;
			  counter00 <=0;
			 end
		 else if(updn0==1 && moleHeight[0]<118)
	       begin
			    counter00 <= counter00 +1;
				 if(counter00 == 30000) 
				   begin
		           moleHeight[0] <= moleHeight[0] +1;
					  counter00 <=0;
					end
          end	
		 else if(updn0==0)
		    begin
			    moleHeight[0] <= 0;
				 counter00 <=0;
		    end	
		 else 
		    begin
			    moleHeight[0] <= moleHeight[0];
				 counter00 <=0;
		    end	
	  end		 
	  
	  //Calculate the height of the mole1
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[1] <= 0;
			  counter11 <=0;
			 end
		 else if(updn1==1 && moleHeight[1]<118)
	       begin
			    counter11 <= counter11 +1;
				 if(counter11 == 30000) 
				   begin
		           moleHeight[1] <= moleHeight[1] +1;
					  counter11 <=0;
					end
          end	
		 else if(updn1==0)
		    begin
			    moleHeight[1] <= 0;
				 counter11 <=0;
		    end	
		 else 
		    begin
			    moleHeight[1] <= moleHeight[1];
				 counter11 <=0;
		    end	
	  end		 

	  
	  //Calculate the height of the mole2
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[2] <= 0;
			  counter22 <=0;
			 end
		 else if(updn2==1 && moleHeight[2]<118)
	       begin
			    counter22 <= counter22 +1;
				 if(counter22 == 30000) 
				   begin
		           moleHeight[2] <= moleHeight[2] +1;
					  counter22 <=0;
					end
          end	
		 else if(updn2==0)
		    begin
			    moleHeight[2] <= 0;
				 counter22 <=0;
		    end	
		 else 
		    begin
			    moleHeight[2] <= moleHeight[2];
				 counter22 <=0;
		    end	
	  end		 

	  
	  //Calculate the height of the mole3
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[3] <= 0;
			  counter33 <=0;
			 end
		 else if(updn3==1 && moleHeight[3]<118)
	       begin
			    counter33 <= counter33 +1;
				 if(counter33 == 30000) 
				   begin
		           moleHeight[3] <= moleHeight[3] +1;
					  counter33 <=0;
					end
          end	
		 else if(updn3==0)
		    begin
			    moleHeight[3] <= 0;
				 counter33 <=0;
		    end	
		 else 
		    begin
			    moleHeight[3] <= moleHeight[3];
				 counter33 <=0;
		    end	
	  end		 

	  
	  //Calculate the height of the mole4
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[4] <= 0;
			  counter44 <=0;
			 end
		 else if(updn4==1 && moleHeight[4]<118)
	       begin
			    counter44 <= counter44 +1;
				 if(counter44 == 30000) 
				   begin
		           moleHeight[4] <= moleHeight[4] +1;
					  counter44 <=0;
					end
          end	
		 else if(updn4==0)
		    begin
			    moleHeight[4] <= 0;
				 counter44 <=0;
		    end	
		 else 
		    begin
			    moleHeight[4] <= moleHeight[4];
				 counter44 <=0;
		    end	
	  end		 

	  
	  //Calculate the height of the mole5
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[5] <= 0;
			  counter55 <=0;
			 end
		 else if(updn5==1 && moleHeight[5]<118)
	       begin
			    counter55 <= counter55 +1;
				 if(counter55 == 30000) 
				   begin
		           moleHeight[5] <= moleHeight[5] +1;
					  counter55 <=0;
					end
          end	
		 else if(updn5==0)
		    begin
			    moleHeight[5] <= 0;
				 counter55 <=0;
		    end	
		 else 
		    begin
			    moleHeight[5] <= moleHeight[5];
				 counter55 <=0;
		    end	
	  end		 

	  //Calculate the height of the mole6
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[6] <= 0;
			  counter66 <=0;
			 end
		 else if(updn6==1 && moleHeight[6]<118)
	       begin
			    counter66 <= counter66 +1;
				 if(counter66 == 30000) 
				   begin
		           moleHeight[6] <= moleHeight[6] +1;
					  counter66 <=0;
					end
          end	
		 else if(updn6==0)
		    begin
			    moleHeight[6] <= 0;
				 counter66 <=0;
		    end	
		 else 
		    begin
			    moleHeight[6] <= moleHeight[6];
				 counter66 <=0;
		    end	
	  end		 

	  //Calculate the height of the mole7
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[7] <= 0;
			  counter77 <=0;
			 end
		 else if(updn7==1 && moleHeight[7]<118)
	       begin
			    counter77 <= counter77 +1;
				 if(counter77 == 30000) 
				   begin
		           moleHeight[7] <= moleHeight[7] +1;
					  counter77 <=0;
					end
          end	
		 else if(updn7==0)
		    begin
			    moleHeight[7] <= 0;
				 counter77 <=0;
		    end	
		 else 
		    begin
			    moleHeight[7] <= moleHeight[7];
				 counter77 <=0;
		    end	
	  end		 

	  //Calculate the height of the mole8
always@(posedge iCLK or negedge iRST_n)
    begin
	    if(!iRST_n)
		    begin
			  moleHeight[8] <= 0;
			  counter88 <=0;
			 end
		 else if(updn8==1 && moleHeight[8]<118)
	       begin
			    counter88 <= counter88 +1;
				 if(counter88 == 30000) 
				   begin
		           moleHeight[8] <= moleHeight[8] +1;
					  counter88 <=0;
					end
          end	
		 else if(updn8==0)
		    begin
			    moleHeight[8] <= 0;
				 counter88 <=0;
		    end	
		 else 
		    begin
			    moleHeight[8] <= moleHeight[8];
				 counter88 <=0;
		    end	
	  end		 




	
//Detect which area you are in// 0~14 different areas
assign area[0] = ((x_cnt>(Hsync_Blank-1+400)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-200))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0 ; //mole0
assign area[1] = ((x_cnt>(Hsync_Blank-1+200)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-400))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0;//mole1
assign area[2] = ((x_cnt>(Hsync_Blank-1)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-600))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0 ;//mole2
assign area[3] = ((x_cnt>(Hsync_Blank-1+400)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-200))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ;	//mole3
assign area[4] = ((x_cnt>(Hsync_Blank-1+200)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-400))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ; //mole4
assign area[5] = ((x_cnt>(Hsync_Blank-1)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-600))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ;//mole5
assign area[6] = ((x_cnt>(Hsync_Blank-1+400)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-200))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0 ;	//mole6
assign area[7] = ((x_cnt>(Hsync_Blank-1+200)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-400))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0; //mole7
assign area[8] = ((x_cnt>(Hsync_Blank-1)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-600))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0 ;//mole8
assign area[9] = ((x_cnt>(Hsync_Blank-1+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-400))
						))  ? 1'b1 : 1'b0 ;//area 9 Time
assign area[10] = ((x_cnt>(Hsync_Blank-1+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+80))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0 ;//area 10 life
assign area[11] = ((x_cnt>(Hsync_Blank-1+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-240))
						))  ? 1'b1 : 1'b0 ;//area 11 score
assign area[12] = ((x_cnt>(Hsync_Blank-1+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+240))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ;//area 12 start/pause
assign area[13] = ((x_cnt>(Hsync_Blank-1+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-80))
						))  ? 1'b1 : 1'b0 ;//area 13 exit
assign area[14] = ((x_cnt>(Hsync_Blank-1+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+400))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0 ;//area 14 label
assign area[15] = 1'b0;
//area 15 is the logo of the team defalt black						


	
//Test --Allocate color to each block
always@(posedge iCLK or negedge iRST_n)
	begin
	if (!iRST_n)
		begin
		mole_address <= moleBase;
		end
	else
		case(area)
						16'b0000000000000001: begin
			                          x_offset <= Hsync_Blank + 400; 
								      y_offset <= Vertical_Back_Porch;
									 //get the diff between the current x_cnt and the left boundary of the hole
									  bound_x <= 	-x_cnt+x_offset+200-40;
									 //get the diff between the current y_cnt and the horizontal center of the hole 
											  	if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
									               
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[0]>0) 
										            begin 	
														case(mole0)
														  2'b00:begin   //mole
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[0]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[0]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[0]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[0])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
														end
														2'b10:begin  //bottle
														       // bottle out 
															  // inside bottle area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[0]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[0]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[0]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase+bottleOffset + (y_cnt-135-y_offset+moleHeight[0])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
														end
														2'b01:begin  //evil
														       // bottle out 
															  // inside bottle area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[0]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[0]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[0]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase+evilOffset + (y_cnt-135-y_offset+moleHeight[0])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
														end
															  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
			                      end
	

	

			16'b0000000000000010: begin  x_offset <= Hsync_Blank + 200; 
								           y_offset <= Vertical_Back_Porch;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[1]>0) 
										           begin 	
														case(mole1)
														  2'b00:begin   //mole
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[1]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[1]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[1]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[1])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 
											                end 
											                
											                 2'b10:begin   //bottle
														
															  //bottle out 
															  // inside bottle area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[1]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[1]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[1]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset + moleBase + (y_cnt-135-y_offset+moleHeight[1])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 
											                end 
											                
											                 2'b01:begin   //evil
														
															  //evil out 
															  // inside evil area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[1]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[1]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[1]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset + moleBase + (y_cnt-135-y_offset+moleHeight[1])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 
											                end      
											                 
																  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
										 end


			16'b0000000000000100: begin  x_offset <= Hsync_Blank; 
								           y_offset <= Vertical_Back_Porch;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[2]>0) 
										            begin 	
														case(mole2)
														  2'b00:begin   //mole
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[2]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[2]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[2]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[2])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 
											                 end
											                 
											                   2'b10:begin   //bottle
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[2]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[2]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[2]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset+moleBase + (y_cnt-135-y_offset+moleHeight[2])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 
											                 end
											                   2'b01:begin   //evil
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[2]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[2]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[2]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset + moleBase + (y_cnt-135-y_offset+moleHeight[2])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 
											                 end
			  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
										 end
			16'b0000000000001000: begin  x_offset <= Hsync_Blank + 400; 
								           y_offset <= Vertical_Back_Porch + 160;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[3]>0) 
										           begin 	
														case(mole3)
														  2'b00:begin   //mole
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[3]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[3]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[3]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[3])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
															end	  
															2'b10:begin   //bottle
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[3]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[3]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[3]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset + moleBase + (y_cnt-135-y_offset+moleHeight[3])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
															end	
															
															2'b01:begin   //evil
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[3]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[3]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[3]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset + moleBase + (y_cnt-135-y_offset+moleHeight[3])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
															end
																  
																  
																  
																  
																  
																  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
										 end
			16'b0000000000010000: begin  x_offset <= Hsync_Blank + 200; 
								           y_offset <= Vertical_Back_Porch + 160;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[4]>0) 
										             begin 	
														case(mole4)
														  2'b00:begin   //mole
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[4]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[4]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[4]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[4])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                  2'b10:begin   //bottle
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[4]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[4]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[4]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset + moleBase + (y_cnt-135-y_offset+moleHeight[4])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 2'b01:begin   //evil
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[4]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[4]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[4]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset + moleBase + (y_cnt-135-y_offset+moleHeight[4])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 
											                 
											                 
																  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
										 end
			16'b0000000000100000: begin  x_offset <= Hsync_Blank ; 
								           y_offset <= Vertical_Back_Porch +160;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[5]>0) 
										             begin 	
														case(mole5)
														  2'b00:begin   //mole	
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[5]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[5]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[5]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[5])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 2'b10:begin   //bottle	
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[5]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[5]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[5]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset + moleBase + (y_cnt-135-y_offset+moleHeight[5])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 2'b01:begin   //evil
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[5]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[5]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[5]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset + moleBase + (y_cnt-135-y_offset+moleHeight[5])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
																  
																  
																  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
										 end
			16'b0000000001000000: begin  x_offset <= Hsync_Blank + 400; 
								           y_offset <= Vertical_Back_Porch +320;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[6]>0) 
										           begin 	
														case(mole6)
														  2'b00:begin   //mole	
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[6]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[6]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[6]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[6])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                  2'b10:begin   //mole	
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[6]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[6]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[6]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset + moleBase + (y_cnt-135-y_offset+moleHeight[6])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 2'b01:begin   //mole	
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[6]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[6]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[6]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset + moleBase + (y_cnt-135-y_offset+moleHeight[6])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 
											                 
											                 
																  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
														  
										 end
			16'b0000000010000000: begin  x_offset <= Hsync_Blank + 200; 
								           y_offset <= Vertical_Back_Porch +320;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[7]>0) 
										             begin 	
														case(mole7)
														  2'b00:begin   //mole		
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[7]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[7]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[7]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[7])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 2'b10:begin   //mole		
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[7]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[7]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[7]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset + moleBase + (y_cnt-135-y_offset+moleHeight[7])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 2'b01:begin   //mole		
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[7]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[7]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[7]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset + moleBase + (y_cnt-135-y_offset+moleHeight[7])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
											                 end
											                 
											                 
											                 
																  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
										 end
			16'b0000000100000000: begin x_offset <= Hsync_Blank; 
								           y_offset <= Vertical_Back_Porch+320;
											  //get the diff between the current x_cnt and the left boundary of the hole
									        bound_x <= 	-x_cnt+x_offset+200-40;
											     //get the diff between the current y_cnt and the horizontal center of the hole 
											  	  if(	y_cnt>120+y_offset) 
										            begin
								                     abs_y <= 	y_cnt-120-y_offset;
											         end
										        else	 
										            begin
										               abs_y <= 	-y_cnt+120+y_offset;
									               end
										        //get the diff between the current x_cnt and the vertical center of the hole 
										        if(x_cnt>100+x_offset)  
										            begin
									                  abs_x <= 	x_cnt-100-x_offset;
											         end
										        else
										            begin
										               abs_x <= 	-x_cnt+100+x_offset;
											         end							  
											        	
										        //mole out of the hole  
										        if(moleHeight[8]>0) 
										             begin 	
														case(mole8)
														  2'b00:begin   //mole		
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[8]&& bound_x > moleLeftBound[y_cnt-135-y_offset+moleHeight[8]]+1 &&bound_x <  moleRightBound[y_cnt-135-y_offset+moleHeight[8]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= moleBase + (y_cnt-135-y_offset+moleHeight[8])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
														end
														
														2'b10:begin   //mole		
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[8]&& bound_x > bottleLeftBound[y_cnt-135-y_offset+moleHeight[8]]+1 &&bound_x <  bottleRightBound[y_cnt-135-y_offset+moleHeight[8]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= bottleOffset+ moleBase + (y_cnt-135-y_offset+moleHeight[8])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
														end
														
														2'b01:begin   //mole		
														
															  //mole out 
															  // inside mole area  
											              if  (y_cnt < y_offset + 135 && y_cnt > y_offset + 135 - moleHeight[8]&& bound_x > evilLeftBound[y_cnt-135-y_offset+moleHeight[8]]+1 &&bound_x <  evilRightBound[y_cnt-135-y_offset+moleHeight[8]]-1  )
												              begin
																    //update the mole_address
													             mole_address <= evilOffset+ moleBase + (y_cnt-135-y_offset+moleHeight[8])*120 + x_cnt-x_offset-40;
																	 moleExist <= 1;
											                 end 	
															  //hole area	  
										                 else if( abs_y<15 && abs_x<hole[abs_y] )
										                    begin
																	 moleExist <= 1;
																	 mole_address <= moleBase + 120*120;
											                 end
										                 else
										                    begin 
																	 moleExist <= 0;
																	 mole_address <= 18'bZ ;
											                 end
														end
																  
																  
																  
																  
										            endcase
														end
											    //no mole			
												 else 
												   if( abs_y<15 && abs_x<hole[abs_y] )
										              begin
															 moleExist <= 1;
															 mole_address <= moleBase + 120*120;
											           end
										         else
										              begin 
															  moleExist <= 0;
															  mole_address <= 18'bZ ;
											           end 
										 end
			16'b0000001000000000: begin moleExist <= 0;
															  mole_address <= 18'bZ ;end
			16'b0000010000000000: begin moleExist <= 0;
															  mole_address <= 18'bZ ;end
			16'b0000100000000000: begin moleExist <= 0;
															  mole_address <= 18'bZ ;end
			16'b0001000000000000: begin moleExist <= 0;
															  mole_address <= 18'bZ ;end
			16'b0010000000000000: begin moleExist <= 0;
															  mole_address <= 18'bZ ;end
			16'b0100000000000000: begin moleExist <= 0;
															  mole_address <= 18'bZ ;end
			16'b1000000000000000: begin moleExist <= 0;
															  mole_address <= 18'bZ ;end
			default: begin moleExist <= 0;
															  mole_address <= 18'bZ ;	end
		endcase
	end

						
endmodule











