module play(
				iclk,
				ireset_n,
				ix_cnt, // input from lcd controlelr
				iy_cnt, // input from lcd controller
				iPANELCTRL, // command from nios containing 32 bits
				iMOLECTRL,
				oADDR, //the output address to the lcd controller
					);
//============================================================================
// PARAMETER declarations
//============================================================================
parameter H_LINE = 1056;
parameter V_LINE = 525;
parameter Hsync_Blank = 216;
parameter Hsync_Front_Porch = 40;
parameter Vertical_Back_Porch = 35;
parameter Vertical_Front_Porch = 10;
parameter offset = 32000; //control panel image address offset	

//===============================================
//I/O DECALARATION===============================
//===============================================		
input iclk;
input ireset_n;
input [10:0] ix_cnt;
input [9:0] iy_cnt;	
input [31:0] iPANELCTRL;
input [31:0] iMOLECTRL;
output [17:0] oADDR;

//===============================================
//WIRE & REG===============================
//===============================================
wire [1:0] override;
wire [17:0] MOLE_ADDR;
wire [17:0] PANEL_ADDR;
reg [17:0] BACK_ADDR;
wire [15:0] area;
wire [10:0] x_cnt;
wire [9:0] y_cnt;
reg [15:0] area_counter[0:15];
wire state = iPANELCTRL[3:0];

assign oADDR = (override[1]) ? MOLE_ADDR : (override[0]) ? PANEL_ADDR : BACK_ADDR;
assign x_cnt = ix_cnt;
assign y_cnt = iy_cnt;
			
mole_ctrl mole_ctrl1(
						.iCLK(iclk), 				// LCD display clock
						.iRST_n(ireset_n), 			// systen reset
					   .x_cnt(x_cnt),  
                  .y_cnt(y_cnt), 
						.moleControl(iMOLECTRL),
						.moleExist(override[1]),
						.mole_address(MOLE_ADDR),
						);
						
panel_ctrl panel_ctrl1(
					.clk_ltm(iclk),
					.reset_n(ireset_n), //top level connection
					.x_cnt(x_cnt), // input from lcd controlelr
					.y_cnt(y_cnt), // input from lcd controller
					.iPANELCTRL(iPANELCTRL), // command from nios containing 32 bits
					.oOVERRIDE(override[0]),//override output to the lcd_controller
					.oADDR(PANEL_ADDR) //the output address to the lcd controller
					);
				
//Detect which area you are in// 0~14 different areas//offset corrected
assign area[0] = ((x_cnt>(Hsync_Blank-2+400)&& //>214
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-200))&& //< 1015
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0 ; //mole0
assign area[1] = ((x_cnt>(Hsync_Blank-2+200)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-400))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0;//mole1
assign area[2] = ((x_cnt>(Hsync_Blank-2)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-600))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0 ;//mole2
assign area[3] = ((x_cnt>(Hsync_Blank-2+400)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-200))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ;	//mole3
assign area[4] = ((x_cnt>(Hsync_Blank-2+200)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-400))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ; //mole4
assign area[5] = ((x_cnt>(Hsync_Blank-2)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-600))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ;//mole5
assign area[6] = ((x_cnt>(Hsync_Blank-2+400)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-200))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0 ;	//mole6
assign area[7] = ((x_cnt>(Hsync_Blank-2+200)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-400))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0; //mole7
assign area[8] = ((x_cnt>(Hsync_Blank-2)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1-600))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0 ;//mole8
assign area[9] = ((x_cnt>(Hsync_Blank-2+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-400))
						))  ? 1'b1 : 1'b0 ;//area 9 Time
assign area[10] = ((x_cnt>(Hsync_Blank-2+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+80))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-320))
						))  ? 1'b1 : 1'b0 ;//area 10 life
assign area[11] = ((x_cnt>(Hsync_Blank-2+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+160))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-240))
						))  ? 1'b1 : 1'b0 ;//area 11 score
assign area[12] = ((x_cnt>(Hsync_Blank-2+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+240))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-160))
						))  ? 1'b1 : 1'b0 ;//area 12 start/pause
assign area[13] = ((x_cnt>(Hsync_Blank-2+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+320))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch-80))
						))  ? 1'b1 : 1'b0 ;//area 13 exit
assign area[14] = ((x_cnt>(Hsync_Blank-2+600)&& //>215
						(x_cnt<(H_LINE-Hsync_Front_Porch-1))&& //< 1016
						(y_cnt>(Vertical_Back_Porch-1+400))&& 
						(y_cnt<(V_LINE - Vertical_Front_Porch))
						))  ? 1'b1 : 1'b0 ;//area 14 label
	

always@(posedge iclk or negedge ireset_n)
begin
	if(!ireset_n)
		BACK_ADDR <= 18'bZ;
	else
      BACK_ADDR <=  	    area[0] ? area_counter[0] : 
								 area[1] ? area_counter[1] :
								 area[2] ? area_counter[2] : 
								 area[3] ? area_counter[3] :
								 area[4] ? area_counter[4] : 
								 area[5] ? area_counter[5] :
								 area[6] ? area_counter[6] : 
								 area[7] ? area_counter[7] :
								 area[8] ? area_counter[8] : 
								 area[9] ? (area_counter[9] + offset):
								 area[10] ? (area_counter[10] + offset): 
								 area[11] ? (area_counter[11] + offset):
								 area[12] ? (area_counter[12] + offset): 
								 area[13] ? (area_counter[13] + offset):
								 area[14] ? (area_counter[14] + offset): 18'bZ;
end	

always@(posedge iclk or negedge ireset_n)
	begin
	if (!ireset_n)
		begin
		area_counter[0] <= 0;
		area_counter[1] <= 0;
		area_counter[2] <= 0;
		area_counter[3] <= 0;
		area_counter[4] <= 0;
		area_counter[5] <= 0;
		area_counter[6] <= 0;
		area_counter[7] <= 0;
		area_counter[8] <= 0;
		area_counter[9] <= 0;
		area_counter[10] <= 0;
		area_counter[11] <= 0;
		area_counter[12] <= 0;
		area_counter[13] <= 0;
		area_counter[14] <= 0;
		end
	else
		case(area)
			16'b0000000000000001: 
			begin 
			if(area_counter[0] == 15'd31999)
				area_counter[0] <= 0;
			else
				area_counter[0] <= area_counter[0] +1;
			end//area 0 
			
			16'b0000000000000010: 
			begin 
			if(area_counter[1] == 15'd31999)
				area_counter[1] <= 0;
			else
				area_counter[1] <= area_counter[1] +1;
			end//area 1
			
			16'b0000000000000100: 
			begin 
			if(area_counter[2] == 15'd31999)
				area_counter[2] <= 0;
			else
				area_counter[2] <= area_counter[2] +1;
			end//area 2
			
			16'b0000000000001000: 
			begin 
			if(area_counter[3] == 15'd31999)
				area_counter[3] <= 0;
			else
				area_counter[3] <= area_counter[3] +1;
			end//area 3
			
			16'b0000000000010000: 
			begin 
			if(area_counter[4] == 15'd31999)
				area_counter[4] <= 0;
			else
				area_counter[4] <= area_counter[4] +1;
			end//area 4
			
			16'b0000000000100000: 
			begin 
			if(area_counter[5] == 15'd31999)
				area_counter[5] <= 0;
			else
				area_counter[5] <= area_counter[5] +1;
			end//area 5
			
			16'b0000000001000000: 
			begin 
			if(area_counter[6] == 15'd31999)
				area_counter[6] <= 0;
			else
				area_counter[6] <= area_counter[6] +1;
			end//area 6
			
			16'b0000000010000000: 
			begin 
			if(area_counter[7] == 15'd31999)
				area_counter[7] <= 0;
			else
				area_counter[7] <= area_counter[7] +1;
			end//area 7
			
			16'b0000000100000000: 
			begin 
			if(area_counter[8] == 15'd31999)
				area_counter[8] <= 0;
			else
				area_counter[8] <= area_counter[8] +1;
			end//area 8
			
			16'b0000001000000000: 
			begin 
			if(area_counter[9] == 15'd15999)
				area_counter[9] <= 0;
			else
				area_counter[9] <= area_counter[9] +1;
			end//area 9
			
			16'b0000010000000000: 
				begin 
			if(area_counter[10] == 15'd15999)
				area_counter[10] <= 0;
			else
				area_counter[10] <= area_counter[10] +1;
			end//area 10
			
			16'b0000100000000000: 
			begin 
			if(area_counter[11] == 15'd15999)
				area_counter[11] <= 0;
			else
				area_counter[11] <= area_counter[11] +1;
			end//area 11
			
			16'b0001000000000000: 
			begin 
			if(area_counter[12] == 15'd15999)
				area_counter[12] <= 0;
			else
				area_counter[12] <= area_counter[12] +1;
			end//area 12
			
			16'b0010000000000000: 
			begin 
			if(area_counter[13] == 15'd15999)
				area_counter[13] <= 0;
			else
				area_counter[13] <= area_counter[13] +1;
			end//area 13
			
			16'b0100000000000000: 
			begin 
			if(area_counter[14] == 15'd15999)
				area_counter[14] <= 0;
			else
				area_counter[14] <= area_counter[14] +1;
			end//area 14
			
			//default: begin red_1 <= 8'd255;green_1 <= 8'd255;blue_1 <= 8'd255;	end
		endcase
	end
endmodule
						